@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Begin's Transformations:
@@ -72,20 +68,21 @@ private:
     AstNodeFTask*       m_ftaskp;       // Current function/task
     string              m_namedScope;   // Name of begin blocks above us
     string              m_unnamedScope; // Name of begin blocks, including unnamed blocks
-    int                 m_repeatNum;    // Repeat counter
     int                 m_ifDepth;      // Current if depth
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
     // VISITORS
-    virtual void visit(AstNodeModule* nodep) {
-        m_modp = nodep;
-        m_repeatNum = 0;
-        iterateChildren(nodep);
-        m_modp = NULL;
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        AstNodeModule* origModp = m_modp;
+        {
+            m_modp = nodep;
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
     }
-    virtual void visit(AstNodeFTask* nodep) {
+    virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
         UINFO(8,"  "<<nodep<<endl);
         // Rename it
         if (m_unnamedScope != "") {
@@ -110,7 +107,7 @@ private:
         m_namedScope = oldScope;
         m_unnamedScope = oldUnnamed;
     }
-    virtual void visit(AstBegin* nodep) {
+    virtual void visit(AstBegin* nodep) VL_OVERRIDE {
         // Begin blocks were only useful in variable creation, change names and delete
         UINFO(8,"  "<<nodep<<endl);
         string oldScope = m_namedScope;
@@ -124,7 +121,7 @@ private:
                 while ((pos=dottedname.find("__DOT__")) != string::npos) {
                     string ident = dottedname.substr(0, pos);
                     dottedname = dottedname.substr(pos+strlen("__DOT__"));
-                    if (!nodep->unnamed()) {
+                    if (nodep->name() != "") {
                         if (m_namedScope=="") m_namedScope = ident;
                         else m_namedScope = m_namedScope + "__DOT__"+ident;
                     }
@@ -157,9 +154,9 @@ private:
         } else {
             nodep->unlinkFrBack();
         }
-        pushDeletep(nodep); VL_DANGLING(nodep);
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
     }
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         if (m_unnamedScope != "") {
             // Rename it
             nodep->name(m_unnamedScope+"__DOT__"+nodep->name());
@@ -170,7 +167,19 @@ private:
             else m_modp->addStmtp(nodep);
         }
     }
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstTypedef* nodep) VL_OVERRIDE {
+        if (m_unnamedScope != "") {
+            // Rename it
+            nodep->name(m_unnamedScope + "__DOT__" + nodep->name());
+            m_statep->userMarkChanged(nodep);
+            // Move to module
+            nodep->unlinkFrBack();
+            // Begins under funcs just move into the func
+            if (m_ftaskp) m_ftaskp->addStmtsp(nodep);
+            else m_modp->addStmtp(nodep);
+        }
+    }
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         UINFO(8,"   CELL "<<nodep<<endl);
         if (m_namedScope != "") {
             m_statep->userMarkChanged(nodep);
@@ -183,14 +192,14 @@ private:
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstVarXRef* nodep) {
+    virtual void visit(AstVarXRef* nodep) VL_OVERRIDE {
         UINFO(9, "   VARXREF "<<nodep<<endl);
         if (m_namedScope != "" && nodep->inlinedDots() == "") {
             nodep->inlinedDots(m_namedScope);
             UINFO(9, "    rescope to "<<nodep<<endl);
         }
     }
-    virtual void visit(AstScopeName* nodep) {
+    virtual void visit(AstScopeName* nodep) VL_OVERRIDE {
         // If there's a %m in the display text, we add a special node that will contain the name()
         // Similar code in V3Inline
         if (nodep->user1SetOnce()) return;  // Don't double-add text's
@@ -203,13 +212,13 @@ private:
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstCoverDecl* nodep) {
+    virtual void visit(AstCoverDecl* nodep) VL_OVERRIDE {
         // Don't need to fix path in coverage statements, they're not under
         // any BEGINs, but V3Coverage adds them all under the module itself.
         iterateChildren(nodep);
     }
     // VISITORS - LINT CHECK
-    virtual void visit(AstIf* nodep) {  // Note not AstNodeIf; other types don't get covered
+    virtual void visit(AstIf* nodep) VL_OVERRIDE {  // Note not AstNodeIf; other types don't get covered
         // Check IFDEPTH warning - could be in other transform files if desire
         int prevIfDepth = m_ifDepth;
         if (m_ifDepth == -1 || v3Global.opt.ifDepth()<1) {  // Turned off
@@ -223,16 +232,14 @@ private:
         iterateChildren(nodep);
         m_ifDepth = prevIfDepth;
     }
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     BeginVisitor(AstNetlist* nodep, BeginState* statep) {
         m_statep = statep;
         m_modp = NULL;
         m_ftaskp = NULL;
-        m_repeatNum = 0;
         m_ifDepth = 0;
         iterate(nodep);
     }
@@ -249,21 +256,21 @@ private:
     //   AstNodeFTask::user1p           // Node replaced, rename it
 
     // VISITORS
-    virtual void visit(AstNodeFTaskRef* nodep) {
+    virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         if (nodep->taskp()->user1()) {  // It was converted
             UINFO(9, "    relinkFTask "<<nodep<<endl);
             nodep->name(nodep->taskp()->name());
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (nodep->varp()->user1()) {  // It was converted
             UINFO(9, "    relinVarRef "<<nodep<<endl);
             nodep->name(nodep->varp()->name());
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstIfaceRefDType* nodep) {
+    virtual void visit(AstIfaceRefDType* nodep) VL_OVERRIDE {
         // May have changed cell names
         // TypeTable is always after all modules, so names are stable
         UINFO(8,"   IFACEREFDTYPE "<<nodep<<endl);
@@ -272,9 +279,8 @@ private:
         iterateChildren(nodep);
     }
     //--------------------
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     BeginRelinkVisitor(AstNetlist* nodep, BeginState*) {
