@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Case's Transformations:
@@ -62,7 +58,7 @@ private:
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
-    virtual void visit(AstNodeCase* nodep) {
+    virtual void visit(AstNodeCase* nodep) VL_OVERRIDE {
         if (VN_IS(nodep, Case) && VN_CAST(nodep, Case)->casex()) {
             nodep->v3warn(CASEX, "Suggest casez (with ?'s) in place of casex (with X's)");
         }
@@ -89,7 +85,7 @@ private:
             m_caseExprp = NULL;
         }
     }
-    virtual void visit(AstConst* nodep) {
+    virtual void visit(AstConst* nodep) VL_OVERRIDE {
         // See also neverItem
         if (m_caseExprp && nodep->num().isFourState()) {
             if (VN_IS(m_caseExprp, GenCase)) {
@@ -106,9 +102,8 @@ private:
             }
         }
     }
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     explicit CaseLintVisitor(AstNodeCase* nodep) {
@@ -250,7 +245,7 @@ private:
                 if (m_valueItem[a] != m_valueItem[b]) { same = false; break; }
             }
             if (same) {
-                tree1p->deleteTree(); VL_DANGLING(tree1p);
+                VL_DO_DANGLING(tree1p->deleteTree(), tree1p);
                 return tree0p;
             }
 
@@ -299,8 +294,8 @@ private:
 
         if (ifrootp) nodep->replaceWith(ifrootp);
         else nodep->unlinkFrBack();
-        nodep->deleteTree(); VL_DANGLING(nodep);
-        cexprp->deleteTree(); VL_DANGLING(cexprp);
+        VL_DO_DANGLING(nodep->deleteTree(), nodep);
+        VL_DO_DANGLING(cexprp->deleteTree(), cexprp);
         if (debug()>=9) ifrootp->dumpTree(cout, "    _simp: ");
     }
 
@@ -331,21 +326,14 @@ private:
                     AstConst* iconstp = VN_CAST(icondp, Const);
                     if (iconstp && neverItem(nodep, iconstp)) {
                         // X in casez can't ever be executed
-                        icondp->deleteTree(); VL_DANGLING(icondp); VL_DANGLING(iconstp);
+                        VL_DO_DANGLING(icondp->deleteTree(), icondp); VL_DANGLING(iconstp);
                         // For simplicity, make expression that is not equal, and let later
                         // optimizations remove it
                         condp = new AstConst(itemp->fileline(), AstConst::LogicFalse());
                     } else if (AstInsideRange* irangep = VN_CAST(icondp, InsideRange)) {
                         // Similar logic in V3Width::visit(AstInside)
-                        AstNode* ap = AstGte::newTyped(itemp->fileline(),
-                                                       cexprp->cloneTree(false),
-                                                       irangep->lhsp()->unlinkFrBack());
-                        AstNode* bp = AstLte::newTyped(itemp->fileline(),
-                                                       cexprp->cloneTree(false),
-                                                       irangep->rhsp()->unlinkFrBack());
-                        ap->fileline()->modifyWarnOff(V3ErrorCode::UNSIGNED, true);
-                        bp->fileline()->modifyWarnOff(V3ErrorCode::CMPCONST, true);
-                        condp = new AstAnd(itemp->fileline(), ap, bp);
+                        condp = irangep->newAndFromInside(cexprp, irangep->lhsp()->unlinkFrBack(),
+                                                          irangep->rhsp()->unlinkFrBack());
                     } else if (iconstp && iconstp->num().isFourState()
                                && (nodep->casex() || nodep->casez() || nodep->caseInside())) {
                         V3Number nummask (itemp, iconstp->width());
@@ -357,7 +345,7 @@ private:
                         AstNode* and2p = new AstAnd(itemp->fileline(),
                                                     new AstConst(itemp->fileline(), numval),
                                                     new AstConst(itemp->fileline(), nummask));
-                        icondp->deleteTree(); VL_DANGLING(icondp); VL_DANGLING(iconstp);
+                        VL_DO_DANGLING(icondp->deleteTree(), icondp); VL_DANGLING(iconstp);
                         condp = AstEq::newTyped(itemp->fileline(), and1p, and2p);
                     } else {
                         // Not a caseX mask, we can simply build CASEEQ(cexpr icond)
@@ -375,7 +363,7 @@ private:
                 itemp->condsp(ifexprp);
             }
         }
-        cexprp->deleteTree(); VL_DANGLING(cexprp);
+        VL_DO_DANGLING(cexprp->deleteTree(), cexprp);
         if (!hadDefault) {
             // If there was no default, add a empty one, this greatly simplifies below code
             // and constant propagation will just eliminate it for us later.
@@ -418,7 +406,7 @@ private:
             {   // Make the new lower IF and attach in the tree
                 AstNode* itemexprp = ifexprp; VL_DANGLING(ifexprp);
                 if (depth == (CASE_ENCODER_GROUP_DEPTH)) {  // End of group - can skip the condition
-                    itemexprp->deleteTree(); VL_DANGLING(itemexprp);
+                    VL_DO_DANGLING(itemexprp->deleteTree(), itemexprp);
                     itemexprp = new AstConst(itemp->fileline(), AstConst::LogicTrue());
                 }
                 AstIf* newp = new AstIf(itemp->fileline(), itemexprp, istmtsp, NULL);
@@ -434,7 +422,7 @@ private:
         if (debug()>=9 && grouprootp) grouprootp->dumpTree(cout, "     _new: ");
         if (grouprootp) nodep->replaceWith(grouprootp);
         else nodep->unlinkFrBack();
-        nodep->deleteTree(); VL_DANGLING(nodep);
+        VL_DO_DANGLING(nodep->deleteTree(), nodep);
     }
 
     void replaceCaseParallel(AstCase* nodep, bool noOverlapsAllCovered) {
@@ -460,7 +448,7 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstCase* nodep) {
+    virtual void visit(AstCase* nodep) VL_OVERRIDE {
         V3Case::caseLint(nodep);
         iterateChildren(nodep);
         if (debug()>=9) nodep->dumpTree(cout, " case_old: ");
@@ -468,17 +456,14 @@ private:
             // It's a simple priority encoder or complete statement
             // we can make a tree of statements to avoid extra comparisons
             ++m_statCaseFast;
-            replaceCaseFast(nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(replaceCaseFast(nodep), nodep);
         } else {
             ++m_statCaseSlow;
-            replaceCaseComplicated(nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(replaceCaseComplicated(nodep), nodep);
         }
     }
     //--------------------
-    // Default: Just iterate
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
