@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Changed's Transformations:
@@ -97,7 +93,7 @@ public:
                                                new AstLogOr(m_scopetopp->fileline(), callp,
                                                             returnp->lhsp()->unlinkFrBack()));
                 returnp->replaceWith(newp);
-                returnp->deleteTree(); VL_DANGLING(returnp);
+                VL_DO_DANGLING(returnp->deleteTree(), returnp);
             }
             m_numStmts = 0;
         }
@@ -148,13 +144,13 @@ private:
         m_statep->m_numStmts += visitor.count();
     }
 
-    virtual void visit(AstBasicDType* nodep) {
+    virtual void visit(AstBasicDType* nodep) VL_OVERRIDE {
         newChangeDet();
     }
-    virtual void visit(AstPackArrayDType* nodep) {
+    virtual void visit(AstPackArrayDType* nodep) VL_OVERRIDE {
         newChangeDet();
     }
-    virtual void visit(AstUnpackArrayDType* nodep) {
+    virtual void visit(AstUnpackArrayDType* nodep) VL_OVERRIDE {
         for (int index=0; index < nodep->elementsConst(); ++index) {
             AstNode* origVEp = m_varEqnp;
             AstNode* origNLEp = m_newLvEqnp;
@@ -175,7 +171,7 @@ private:
             m_newRvEqnp = origNREp;
         }
     }
-    virtual void visit(AstNodeUOrStructDType* nodep) {
+    virtual void visit(AstNodeUOrStructDType* nodep) VL_OVERRIDE {
         if (nodep->packedUnsup()) {
             newChangeDet();
         } else {
@@ -185,7 +181,7 @@ private:
                            <<m_vscp->varp()->prettyNameQ());
         }
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         if (debug()) nodep->dumpTree(cout, "-DETECTARRAY-general-");
         m_vscp->v3warn(E_DETECTARRAY, "Unsupported: Can't detect changes on complex variable"
@@ -247,7 +243,7 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         UINFO(4," MOD   "<<nodep<<endl);
         if (nodep->isTop()) {
             m_statep->m_topModp = nodep;
@@ -255,7 +251,7 @@ private:
         iterateChildren(nodep);
     }
 
-    virtual void visit(AstTopScope* nodep) {
+    virtual void visit(AstTopScope* nodep) VL_OVERRIDE {
         UINFO(4," TS "<<nodep<<endl);
         // Clearing
         AstNode::user1ClearTree();
@@ -279,7 +275,7 @@ private:
 
         iterateChildren(nodep);
     }
-    virtual void visit(AstVarScope* nodep) {
+    virtual void visit(AstVarScope* nodep) VL_OVERRIDE {
         if (nodep->isCircular()) {
             UINFO(8,"  CIRC "<<nodep<<endl);
             if (!nodep->user1SetOnce()) {
@@ -287,14 +283,9 @@ private:
             }
         }
     }
-    virtual void visit(AstNodeMath* nodep) {
-        // Short-circuit
-    }
     //--------------------
-    // Default: Just iterate
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
