@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // COVERAGE TRANSFORMATIONS:
@@ -54,8 +50,8 @@ private:
             : m_comment(comment), m_varRefp(vp), m_chgRefp(cp) {}
         ~ToggleEnt() {}
         void cleanup() {
-            m_varRefp->deleteTree(); m_varRefp = NULL;
-            m_chgRefp->deleteTree(); m_chgRefp = NULL;
+            VL_DO_CLEAR(m_varRefp->deleteTree(), m_varRefp = NULL);
+            VL_DO_CLEAR(m_chgRefp->deleteTree(), m_chgRefp = NULL);
         }
     };
 
@@ -149,17 +145,21 @@ private:
             +"_"+type;
     }
     // VISITORS - BOTH
-    virtual void visit(AstNodeModule* nodep) {
-        m_modp = nodep;
-        m_inModOff = nodep->isTop();  // Ignore coverage on top module; it's a shell we created
-        m_fileps.clear();
-        iterateChildren(nodep);
-        m_modp = NULL;
-        m_inModOff = true;
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        AstNodeModule* origModp = m_modp;
+        bool origInModOff = m_inModOff;
+        {
+            m_modp = nodep;
+            m_inModOff = nodep->isTop();  // Ignore coverage on top module; it's a shell we created
+            m_fileps.clear();
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
+        m_inModOff = origInModOff;
     }
 
     // VISITORS - TOGGLE COVERAGE
-    virtual void visit(AstNodeFTask* nodep) {
+    virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
         bool oldtog = m_inToggleOff;
         {
             m_inToggleOff = true;
@@ -167,7 +167,7 @@ private:
         }
         m_inToggleOff = oldtog;
     }
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         if (m_modp && !m_inModOff && !m_inToggleOff
             && nodep->fileline()->coverageOn() && v3Global.opt.coverageToggle()) {
@@ -303,7 +303,7 @@ private:
     }
 
     // VISITORS - LINE COVERAGE
-    virtual void visit(AstIf* nodep) {  // Note not AstNodeIf; other types don't get covered
+    virtual void visit(AstIf* nodep) VL_OVERRIDE {  // Note not AstNodeIf; other types don't get covered
         UINFO(4," IF: "<<nodep<<endl);
         if (m_checkBlock) {
             // An else-if.  When we iterate the if, use "elsif" marking
@@ -340,7 +340,7 @@ private:
             m_checkBlock = true;  // Reset as a child may have cleared it
         }
     }
-    virtual void visit(AstCaseItem* nodep) {
+    virtual void visit(AstCaseItem* nodep) VL_OVERRIDE {
         UINFO(4," CASEI: "<<nodep<<endl);
         if (m_checkBlock && !m_inModOff
             && nodep->fileline()->coverageOn() && v3Global.opt.coverageLine()) {
@@ -353,7 +353,7 @@ private:
             m_checkBlock = true;  // Reset as a child may have cleared it
         }
     }
-    virtual void visit(AstCover* nodep) {
+    virtual void visit(AstCover* nodep) VL_OVERRIDE {
         UINFO(4," COVER: "<<nodep<<endl);
         m_checkBlock = true;  // Always do cover blocks, even if there's a $stop
         iterateChildren(nodep);
@@ -364,21 +364,21 @@ private:
         }
         m_checkBlock = true;  // Reset as a child may have cleared it
     }
-    virtual void visit(AstStop* nodep) {
+    virtual void visit(AstStop* nodep) VL_OVERRIDE {
         UINFO(4,"  STOP: "<<nodep<<endl);
         m_checkBlock = false;
     }
-    virtual void visit(AstPragma* nodep) {
+    virtual void visit(AstPragma* nodep) VL_OVERRIDE {
         if (nodep->pragType() == AstPragmaType::COVERAGE_BLOCK_OFF) {
             // Skip all NEXT nodes under this block, and skip this if/case branch
             UINFO(4,"  OFF: "<<nodep<<endl);
             m_checkBlock = false;
-            nodep->unlinkFrBack()->deleteTree(); VL_DANGLING(nodep);
+            VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
         } else {
             if (m_checkBlock) iterateChildren(nodep);
         }
     }
-    virtual void visit(AstBegin* nodep) {
+    virtual void visit(AstBegin* nodep) VL_OVERRIDE {
         // Record the hierarchy of any named begins, so we can apply to user
         // coverage points.  This is because there may be cov points inside
         // generate blocks; each point should get separate consideration.
@@ -398,8 +398,7 @@ private:
     }
 
     // VISITORS - BOTH
-    virtual void visit(AstNode* nodep) {
-        // Default: Just iterate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         if (m_checkBlock) {
             iterateChildren(nodep);
             m_checkBlock = true;  // Reset as a child may have cleared it
