@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -58,7 +54,7 @@ V3ErrorCode::V3ErrorCode(const char* msgp) {
     // Return error encoding for given string, or ERROR, which is a bad code
     for (int codei=V3ErrorCode::EC_MIN; codei<V3ErrorCode::_ENUM_MAX; codei++) {
         V3ErrorCode code = V3ErrorCode(codei);
-        if (0==strcasecmp(msgp, code.ascii())) {
+        if (0 == VL_STRCASECMP(msgp, code.ascii())) {
             m_e = code; return;
         }
     }
@@ -92,30 +88,32 @@ string V3Error::lineStr(const char* filename, int lineno) {
 void V3Error::incErrors() {
     s_errCount++;
     if (errorCount() == errorLimit()) {  // Not >= as would otherwise recurse
-        v3fatal("Exiting due to too many errors encountered; --error-limit="<<errorCount()<<endl);
+        v3fatalExit("Exiting due to too many errors encountered; --error-limit="
+                    << errorCount() << endl);
     }
 }
 
 void V3Error::abortIfWarnings() {
     bool exwarn = warnFatal() && warnCount();
     if (errorCount() && exwarn) {
-        v3fatal("Exiting due to "<<std::dec<<errorCount()<<" error(s), "
-                <<warnCount()<<" warning(s)\n");
+        v3fatalExit("Exiting due to " << std::dec << errorCount() << " error(s), "
+                    << warnCount() << " warning(s)\n");
     } else if (errorCount()) {
-        v3fatal("Exiting due to "<<std::dec<<errorCount()<<" error(s)\n");
+        v3fatalExit("Exiting due to " << std::dec << errorCount() << " error(s)\n");
     } else if (exwarn) {
-        v3fatal("Exiting due to "<<std::dec<<warnCount()<<" warning(s)\n");
+        v3fatalExit("Exiting due to " << std::dec << warnCount() << " warning(s)\n");
     }
 }
 
 bool V3Error::isError(V3ErrorCode code, bool supp) {
     if (supp) return false;
-    else if (code==V3ErrorCode::USERINFO) return false;
-    else if (code==V3ErrorCode::EC_INFO) return false;
-    else if (code==V3ErrorCode::EC_FATAL) return true;
-    else if (code==V3ErrorCode::EC_FATALSRC) return true;
-    else if (code==V3ErrorCode::EC_ERROR) return true;
-    else if (code<V3ErrorCode::EC_FIRST_WARN
+    else if (code == V3ErrorCode::USERINFO) return false;
+    else if (code == V3ErrorCode::EC_INFO) return false;
+    else if (code == V3ErrorCode::EC_FATAL) return true;
+    else if (code == V3ErrorCode::EC_FATALEXIT) return true;
+    else if (code == V3ErrorCode::EC_FATALSRC) return true;
+    else if (code == V3ErrorCode::EC_ERROR) return true;
+    else if (code < V3ErrorCode::EC_FIRST_WARN
              || s_pretendError[code]) return true;
     else return false;
 }
@@ -124,11 +122,12 @@ string V3Error::msgPrefix() {
     V3ErrorCode code = s_errorCode;
     bool supp = s_errorSuppressed;
     if (supp) return "-arning-suppressed: ";
-    else if (code==V3ErrorCode::USERINFO) return "-Info: ";
-    else if (code==V3ErrorCode::EC_INFO) return "-Info: ";
-    else if (code==V3ErrorCode::EC_FATAL) return "%Error: ";
-    else if (code==V3ErrorCode::EC_FATALSRC) return "%Error: Internal Error: ";
-    else if (code==V3ErrorCode::EC_ERROR) return "%Error: ";
+    else if (code == V3ErrorCode::USERINFO) return "-Info: ";
+    else if (code == V3ErrorCode::EC_INFO) return "-Info: ";
+    else if (code == V3ErrorCode::EC_FATAL) return "%Error: ";
+    else if (code == V3ErrorCode::EC_FATALEXIT) return "%Error: ";
+    else if (code == V3ErrorCode::EC_FATALSRC) return "%Error: Internal Error: ";
+    else if (code == V3ErrorCode::EC_ERROR) return "%Error: ";
     else if (isError(code, supp)) return "%Error-"+string(code.ascii())+": ";
     else return "%Warning-"+string(code.ascii())+": ";
 }
@@ -194,7 +193,15 @@ void V3Error::v3errorEnd(std::ostringstream& sstr, const string& locationStr) {
         msg.insert(pos + 1, locationMsg);
     }
     // Output
-    std::cerr<<msg;
+    if (
+#ifndef _V3ERROR_NO_GLOBAL_
+        !(v3Global.opt.quietExit() && s_errorCode == V3ErrorCode::EC_FATALEXIT)
+#else
+        true
+#endif
+        ) {
+        std::cerr << msg;
+    }
     if (!s_errorSuppressed && !(s_errorCode==V3ErrorCode::EC_INFO
                                 || s_errorCode==V3ErrorCode::USERINFO)) {
         if (!s_describedEachWarn[s_errorCode]
@@ -222,8 +229,9 @@ void V3Error::v3errorEnd(std::ostringstream& sstr, const string& locationStr) {
         }
         if (isError(s_errorCode, s_errorSuppressed)) incErrors();
         else incWarnings();
-        if (s_errorCode==V3ErrorCode::EC_FATAL
-            || s_errorCode==V3ErrorCode::EC_FATALSRC) {
+        if (s_errorCode == V3ErrorCode::EC_FATAL
+            || s_errorCode == V3ErrorCode::EC_FATALEXIT
+            || s_errorCode == V3ErrorCode::EC_FATALSRC) {
             static bool inFatal = false;
             if (!inFatal) {
                 inFatal = true;
