@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Gate's Transformations:
@@ -207,7 +203,7 @@ private:
         }
     }
     // VISITORS
-    virtual void visit(AstNodeVarRef* nodep) {
+    virtual void visit(AstNodeVarRef* nodep) VL_OVERRIDE {
         ++m_ops;
         iterateChildren(nodep);
         // We only allow a LHS ref for the var being set, and a RHS ref for
@@ -219,23 +215,19 @@ private:
             if (m_lhsVarRef) clearSimple(">1 lhs varRefs");
             m_lhsVarRef = nodep;
         } else {
-            if (m_rhsVarRefs.size()>1) {
+            if (m_rhsVarRefs.size() > 1) {
                 AstNodeVarRef* lastRefp = m_rhsVarRefs.back();
-                if (0) {  // Disable the multiple-input optimization
-                    clearSimple(">1 rhs varRefs");
-                } else {
-                    if (m_buffersOnly) clearSimple(">1 rhs varRefs");
-                    if (!nodep->varScopep()->varp()->gateMultiInputOptimizable()
-                        // We didn't check multiInput on the first varref, so check it here
-                        || !lastRefp->varScopep()->varp()->gateMultiInputOptimizable()) {
-                        clearSimple("!gateMultiInputOptimizable");
-                    }
+                if (m_buffersOnly) clearSimple(">1 rhs varRefs");
+                if (!nodep->varScopep()->varp()->gateMultiInputOptimizable()
+                    // We didn't check multiInput on the first varref, so check it here
+                    || !lastRefp->varScopep()->varp()->gateMultiInputOptimizable()) {
+                    clearSimple("!gateMultiInputOptimizable");
                 }
             }
             m_rhsVarRefs.push_back(nodep);
         }
     }
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         m_substTreep = nodep->rhsp();
         if (!VN_IS(nodep->lhsp(), NodeVarRef)) {
             clearSimple("ASSIGN(non-VARREF)");
@@ -257,8 +249,7 @@ private:
         }
     }
     //--------------------
-    // Default
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         // *** Special iterator
         if (!m_isSimple) return;  // Fastpath
         if (++m_ops > v3Global.opt.gateStmts()) {
@@ -272,6 +263,7 @@ private:
         }
         else iterateChildren(nodep);
     }
+
 public:
     // CONSTRUCTORS
     GateOkVisitor(AstNode* nodep, bool buffersOnly, bool dedupe) {
@@ -388,7 +380,7 @@ private:
     void decomposeClkVectors();
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         //if (debug()>6) m_graph.dump();
         if (debug()>6) m_graph.dumpDotFilePrefixed("gate_pre");
@@ -419,20 +411,23 @@ private:
         consumedMove();
         replaceAssigns();
     }
-    virtual void visit(AstNodeModule* nodep) {
-        m_modp = nodep;
-        m_activeReducible = true;
-        iterateChildren(nodep);
-        m_modp = NULL;
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        AstNodeModule* origModp = m_modp;
+        {
+            m_modp = nodep;
+            m_activeReducible = true;
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
     }
-    virtual void visit(AstScope* nodep) {
+    virtual void visit(AstScope* nodep) VL_OVERRIDE {
         UINFO(4," SCOPE "<<nodep<<endl);
         m_scopep = nodep;
         m_logicVertexp = NULL;
         iterateChildren(nodep);
         m_scopep = NULL;
     }
-    virtual void visit(AstActive* nodep) {
+    virtual void visit(AstActive* nodep) VL_OVERRIDE {
         // Create required blocks and add to module
         UINFO(4,"  BLOCK  "<<nodep<<endl);
         m_activeReducible = !(nodep->hasClocked());  // Seq logic outputs aren't reducible
@@ -443,16 +438,18 @@ private:
         m_activep = NULL;
         m_activeReducible = true;
     }
-    virtual void visit(AstNodeVarRef* nodep) {
+    virtual void visit(AstNodeVarRef* nodep) VL_OVERRIDE {
         if (m_scopep) {
             UASSERT_OBJ(m_logicVertexp, nodep, "Var ref not under a logic block");
             AstVarScope* varscp = nodep->varScopep();
             UASSERT_OBJ(varscp, nodep, "Var didn't get varscoped in V3Scope.cpp");
             GateVarVertex* vvertexp = makeVarVertex(varscp);
             UINFO(5," VARREF to "<<varscp<<endl);
-            if (m_inSenItem) vvertexp->setIsClock();
-            // For SYNCASYNCNET
-            if (m_inSenItem) varscp->user2(true);
+            if (m_inSenItem) {
+                vvertexp->setIsClock();
+                // For SYNCASYNCNET
+                varscp->user2(true);
+            }
             else if (m_activep && m_activep->hasClocked() && !nodep->lvalue()) {
                 if (varscp->user2()) {
                     if (!vvertexp->rstAsyncNodep()) vvertexp->rstAsyncNodep(nodep);
@@ -469,19 +466,19 @@ private:
             }
         }
     }
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep, (nodep->isJustOneBodyStmt()?NULL:"Multiple Stmts"), NULL);
     }
-    virtual void visit(AstAlwaysPublic* nodep) {
+    virtual void visit(AstAlwaysPublic* nodep) VL_OVERRIDE {
         bool lastslow = m_inSlow;
         m_inSlow = true;
         iterateNewStmt(nodep, "AlwaysPublic", NULL);
         m_inSlow = lastslow;
     }
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep, "User C Function", "User C Function");
     }
-    virtual void visit(AstSenItem* nodep) {
+    virtual void visit(AstSenItem* nodep) VL_OVERRIDE {
         // Note we look at only AstSenItems, not AstSenGate's
         // The gating term of a AstSenGate is normal logic
         m_inSenItem = true;
@@ -492,33 +489,33 @@ private:
         }
         m_inSenItem = false;
     }
-    virtual void visit(AstSenGate* nodep) {
+    virtual void visit(AstSenGate* nodep) VL_OVERRIDE {
         // First handle the clock part will be handled in a minute by visit AstSenItem
         // The logic gating term is dealt with as logic
         iterateNewStmt(nodep, "Clock gater", "Clock gater");
     }
-    virtual void visit(AstInitial* nodep) {
+    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
         bool lastslow = m_inSlow;
         m_inSlow = true;
         iterateNewStmt(nodep, (nodep->isJustOneBodyStmt()?NULL:"Multiple Stmts"), NULL);
         m_inSlow = lastslow;
     }
-    virtual void visit(AstAssignAlias* nodep) {
+    virtual void visit(AstAssignAlias* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep, NULL, NULL);
     }
-    virtual void visit(AstAssignW* nodep) {
+    virtual void visit(AstAssignW* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep, NULL, NULL);
     }
-    virtual void visit(AstCoverToggle* nodep) {
+    virtual void visit(AstCoverToggle* nodep) VL_OVERRIDE {
         iterateNewStmt(nodep, "CoverToggle", "CoverToggle");
     }
-    virtual void visit(AstTraceInc* nodep) {
+    virtual void visit(AstTraceInc* nodep) VL_OVERRIDE {
         bool lastslow = m_inSlow;
         m_inSlow = true;
         iterateNewStmt(nodep, "Tracing", "Tracing");
         m_inSlow = lastslow;
     }
-    virtual void visit(AstConcat* nodep) {
+    virtual void visit(AstConcat* nodep) VL_OVERRIDE {
         UASSERT_OBJ(!(VN_IS(nodep->backp(), NodeAssign)
                       && VN_CAST(nodep->backp(), NodeAssign)->lhsp()==nodep),
                     nodep, "Concat on LHS of assignment; V3Const should have deleted it");
@@ -526,8 +523,7 @@ private:
     }
 
     //--------------------
-    // Default
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         if (nodep->isOutputter() && m_logicVertexp) m_logicVertexp->setConsumed("outputter");
     }
@@ -564,7 +560,7 @@ void GateVisitor::optimizeSignals(bool allowMultiIn) {
                     && !vvertexp->varScp()->varp()->valuep()
                     && !vvertexp->varScp()->varp()->isSigPublic()) {
                     UINFO(4, "No drivers "<<vvertexp->varScp()<<endl);
-                    if (0) {
+                    if (false) {
                         // If we warned here after constant propagation, what the user considered
                         // reasonable logic may have disappeared.  Issuing a warning would
                         // thus be confusing.  V3Undriven now handles this.
@@ -666,7 +662,7 @@ void GateVisitor::optimizeSignals(bool allowMultiIn) {
                                     varvertexp->propagateAttrClocksFrom(vvertexp);
                                 }
                                 // Remove the edge
-                                edgep->unlinkDelete(); VL_DANGLING(edgep);
+                                VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
                                 ++m_statRefs;
                                 edgep = vvertexp->outBeginp();
                             }
@@ -674,7 +670,7 @@ void GateVisitor::optimizeSignals(bool allowMultiIn) {
                         if (removedAllUsages) {
                             // Remove input links
                             while (V3GraphEdge* edgep = vvertexp->inBeginp()) {
-                                edgep->unlinkDelete(); VL_DANGLING(edgep);
+                                VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
                             }
                             // Clone tree so we remember it for tracing, and keep the pointer
                             // to the "ALWAYS" part of the tree as part of this statement
@@ -709,7 +705,7 @@ bool GateVisitor::elimLogicOkOutputs(GateLogicVertex* consumeVertexp,
     for (GateVarRefList::const_iterator it = rhsVarRefs.begin();
          it != rhsVarRefs.end(); ++it) {
         AstVarScope* vscp = (*it)->varScopep();
-        if (varscopes.find(vscp) == varscopes.end()) varscopes.insert(vscp);
+        varscopes.insert(vscp);
     }
     for (V3GraphEdge* edgep = consumeVertexp->outBeginp(); edgep; edgep = edgep->outNextp()) {
         GateVarVertex* consVVertexp = dynamic_cast<GateVarVertex*>(edgep->top());
@@ -731,25 +727,25 @@ void GateVisitor::replaceAssigns() {
             if (vscp->valuep() && !VN_IS(vscp->valuep(), NodeMath)) {
                 //if (debug()>9) vscp->dumpTree(cout, "-vscPre:  ");
                 while (AstNode* delp = VN_CAST(vscp->valuep(), Comment)) {
-                    delp->unlinkFrBack()->deleteTree(); VL_DANGLING(delp);
+                    VL_DO_DANGLING(delp->unlinkFrBack()->deleteTree(), delp);
                 }
                 if (AstInitial* delp = VN_CAST(vscp->valuep(), Initial)) {
                     AstNode* bodyp = delp->bodysp();
                     bodyp->unlinkFrBackWithNext();
                     delp->replaceWith(bodyp);
-                    delp->deleteTree(); VL_DANGLING(delp);
+                    VL_DO_DANGLING(delp->deleteTree(), delp);
                 }
                 if (AstAlways* delp = VN_CAST(vscp->valuep(), Always)) {
                     AstNode* bodyp = delp->bodysp();
                     bodyp->unlinkFrBackWithNext();
                     delp->replaceWith(bodyp);
-                    delp->deleteTree(); VL_DANGLING(delp);
+                    VL_DO_DANGLING(delp->deleteTree(), delp);
                 }
                 if (AstNodeAssign* delp = VN_CAST(vscp->valuep(), NodeAssign)) {
                     AstNode* rhsp = delp->rhsp();
                     rhsp->unlinkFrBack();
                     delp->replaceWith(rhsp);
-                    delp->deleteTree(); VL_DANGLING(delp);
+                    VL_DO_DANGLING(delp->deleteTree(), delp);
                 }
                 //if (debug()>9) {vscp->dumpTree(cout, "-vscDone: "); cout<<endl;}
                 if (!VN_IS(vscp->valuep(), NodeMath)
@@ -805,7 +801,7 @@ void GateVisitor::consumedMove() {
                 // with "tracing-on" sensitivity
                 UINFO(8,"    Remove unconsumed "<<nodep<<endl);
                 nodep->unlinkFrBack();
-                pushDeletep(nodep); VL_DANGLING(nodep);
+                VL_DO_DANGLING(pushDeletep(nodep), nodep);
             }
         }
     }
@@ -860,7 +856,7 @@ private:
     void hashReplace(AstNode* oldp, AstNode* newp);
 
     // VISITORS
-    virtual void visit(AstNodeVarRef* nodep) {
+    virtual void visit(AstNodeVarRef* nodep) VL_OVERRIDE {
         if (nodep->varScopep() == m_elimVarScp) {
             // Substitute in the new tree
             // It's possible we substitute into something that will be reduced more later,
@@ -884,12 +880,11 @@ private:
             if (AstNodeVarRef* varrefp = VN_CAST(substp, NodeVarRef)) varrefp->lvalue(false);
             hashReplace(nodep, substp);
             nodep->replaceWith(substp);
-            nodep->deleteTree(); VL_DANGLING(nodep);
+            VL_DO_DANGLING(nodep->deleteTree(), nodep);
         }
     }
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     virtual ~GateElimVisitor() {}
@@ -1066,7 +1061,7 @@ private:
     bool                m_dedupable;            // Determined the assign to be dedupable
 
     // VISITORS
-    virtual void visit(AstNodeAssign* assignp) {
+    virtual void visit(AstNodeAssign* assignp) VL_OVERRIDE {
         if (m_dedupable) {
             // I think we could safely dedupe an always block with multiple
             // non-blocking statements, but erring on side of caution here
@@ -1077,7 +1072,7 @@ private:
             }
         }
     }
-    virtual void visit(AstAlways* alwaysp) {
+    virtual void visit(AstAlways* alwaysp) VL_OVERRIDE {
         if (m_dedupable) {
             if (!m_always) {
                 m_always = true;
@@ -1091,7 +1086,7 @@ private:
     //  always @(...)
     //    if (...)
     //       foo = ...; // or foo <= ...;
-    virtual void visit(AstNodeIf* ifp) {
+    virtual void visit(AstNodeIf* ifp) VL_OVERRIDE {
         if (m_dedupable) {
             if (m_always && !m_ifCondp && !ifp->elsesp()) {  //we're under an always, this is the first IF,  and there's no else
                 m_ifCondp = ifp->condp();
@@ -1102,10 +1097,10 @@ private:
         }
     }
 
-    virtual void visit(AstComment*) {}  // NOP
+    virtual void visit(AstComment*) VL_OVERRIDE {}  // NOP
     //--------------------
     // Default
-    virtual void visit(AstNode*) {
+    virtual void visit(AstNode*) VL_OVERRIDE {
         m_dedupable = false;
     }
 
@@ -1207,7 +1202,7 @@ private:
                     dupVvertexp->propagateAttrClocksFrom(vvertexp);
                     // Remove inputs links
                     while (V3GraphEdge* inedgep = vvertexp->inBeginp()) {
-                        inedgep->unlinkDelete(); VL_DANGLING(inedgep);
+                        VL_DO_DANGLING(inedgep->unlinkDelete(), inedgep);
                     }
                     // replaceAssigns() does the deleteTree on lvertexNodep in a later step
                     AstNode* lvertexNodep = lvertexp->nodep();
@@ -1338,19 +1333,19 @@ private:
                             UINFO(5, "assemble to new sel: "<<newselp<<endl);
                             // replace preSel with newSel
                             preselp->replaceWith(newselp);
-                            preselp->deleteTree(); VL_DANGLING(preselp);
+                            VL_DO_DANGLING(preselp->deleteTree(), preselp);
                             // create new rhs for pre assignment
                             AstNode* newrhsp = new AstConcat(
                                 m_assignp->rhsp()->fileline(), m_assignp->rhsp()->cloneTree(false),
                                 assignp->rhsp()->cloneTree(false));
                             AstNode* oldrhsp = m_assignp->rhsp();
                             oldrhsp->replaceWith(newrhsp);
-                            oldrhsp->deleteTree(); VL_DANGLING(oldrhsp);
+                            VL_DO_DANGLING(oldrhsp->deleteTree(), oldrhsp);
                             m_assignp->dtypeChgWidthSigned(m_assignp->width()+assignp->width(),
                                                            m_assignp->width()+assignp->width(),
                                                            AstNumeric::SIGNED);
                             // don't need to delete, will be handled
-                            //assignp->unlinkFrBack(); assignp->deleteTree(); VL_DANGLING(assignp);
+                            //assignp->unlinkFrBack(); VL_DO_DANGLING(assignp->deleteTree(), assignp);
 
                             // update the graph
                             {
@@ -1362,11 +1357,11 @@ private:
                                         GateEitherVertex* fromvp
                                             = dynamic_cast<GateEitherVertex*>(oedgep->fromp());
                                         new V3GraphEdge(m_graphp, fromvp, m_logicvp, 1);
-                                        oedgep->unlinkDelete(); VL_DANGLING(oedgep);
+                                        VL_DO_DANGLING(oedgep->unlinkDelete(), oedgep);
                                     }
                                 }
                                 // delete all outedges to lvertexp, only one
-                                oldedgep->unlinkDelete(); VL_DANGLING(oldedgep);
+                                VL_DO_DANGLING(oldedgep->unlinkDelete(), oldedgep);
                             }
                             ++m_numMergedAssigns;
                         } else {
@@ -1425,7 +1420,7 @@ private:
     bool                m_found;        // Offset found
 
     // VISITORS
-    virtual void visit(AstNodeVarRef* nodep) {
+    virtual void visit(AstNodeVarRef* nodep) VL_OVERRIDE {
         UINFO(9,"CLK DECOMP Concat search var (off = "<<m_offset<<") - "<<nodep<<endl);
         if (nodep->varScopep() == m_vscp && !nodep->user2() && !m_found) {
             // A concatenation may use the same var multiple times
@@ -1437,16 +1432,14 @@ private:
         }
         m_offset += nodep->dtypep()->width();
     }
-    virtual void visit(AstConcat* nodep) {
+    virtual void visit(AstConcat* nodep) VL_OVERRIDE {
         UINFO(9,"CLK DECOMP Concat search (off = "<<m_offset<<") - "<<nodep<<endl);
         iterate(nodep->rhsp());
         iterate(nodep->lhsp());
     }
     //--------------------
-    // Default
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     GateConcatVisitor() {
@@ -1556,7 +1549,7 @@ private:
                     AstNode* rhsp = assignp->rhsp();
                     rhsp->replaceWith(new AstVarRef(rhsp->fileline(), m_clk_vsp, false));
                     for (V3GraphEdge* edgep = lvertexp->inBeginp(); edgep; ) {
-                        edgep->unlinkDelete(); VL_DANGLING(edgep);
+                        VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
                     }
                     new V3GraphEdge(m_graphp, m_clk_vvertexp, lvertexp, 1);
                     m_total_decomposed_clk_vectors++;
@@ -1617,21 +1610,19 @@ void GateVisitor::decomposeClkVectors() {
 class GateDeassignVisitor : public GateBaseVisitor {
 private:
     // VISITORS
-    virtual void visit(AstVarScope* nodep) {
+    virtual void visit(AstVarScope* nodep) VL_OVERRIDE {
         if (AstNodeAssign* assp = VN_CAST(nodep->valuep(), NodeAssign)) {
             UINFO(5," Removeassign "<<assp<<endl);
             AstNode* valuep = assp->rhsp();
             valuep->unlinkFrBack();
             assp->replaceWith(valuep);
-            assp->deleteTree(); VL_DANGLING(assp);
+            VL_DO_DANGLING(assp->deleteTree(), assp);
         }
     }
     // Speedups
-    virtual void visit(AstVar* nodep) {}
-    virtual void visit(AstActive* nodep) {}
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstVar*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstActive*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
