@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -224,7 +220,7 @@ void V3Graph::clear() {
     for (V3GraphVertex* vertexp = verticesBeginp(); vertexp; vertexp=vertexp->verticesNextp()) {
         for (V3GraphEdge* edgep = vertexp->outBeginp(); edgep; /*BELOW*/) {
             V3GraphEdge* nextp = edgep->outNextp();
-            delete edgep;
+            VL_DO_DANGLING(delete edgep, edgep);
             edgep = nextp;
         }
         vertexp->outUnlink();
@@ -232,7 +228,7 @@ void V3Graph::clear() {
     // Delete the old vertices
     for (V3GraphVertex* vertexp = verticesBeginp(); vertexp; /*BELOW*/) {
         V3GraphVertex* nextp = vertexp->verticesNextp();
-        delete vertexp;
+        VL_DO_DANGLING(delete vertexp, vertexp);
         vertexp = nextp;
     }
     verticesUnlink();
@@ -350,7 +346,7 @@ void V3Graph::dumpDotFile(const string& filename, bool colorAsSubgraph) const {
     // Print vertices
     int n = 0;
     string subgr;
-    for (SubgraphMmap::iterator it = subgraphs.begin(); it!=subgraphs.end(); ++it) {
+    for (SubgraphMmap::const_iterator it = subgraphs.begin(); it != subgraphs.end(); ++it) {
         string vertexSubgraph = it->first;
         V3GraphVertex* vertexp = it->second;
         numMap[vertexp] = n;
