@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -110,10 +106,10 @@ private:
                     }
                     if (saveOld) {
                         if (m_sumWeights) prevEdgep->weight(prevEdgep->weight() + edgep->weight());
-                        edgep->unlinkDelete(); VL_DANGLING(edgep);
+                        VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
                     } else {
                         if (m_sumWeights) edgep->weight(prevEdgep->weight() + edgep->weight());
-                        prevEdgep->unlinkDelete(); VL_DANGLING(prevEdgep);
+                        VL_DO_DANGLING(prevEdgep->unlinkDelete(), prevEdgep);
                         outVertexp->userp(edgep);
                     }
                 }
@@ -150,9 +146,7 @@ public:
             V3GraphEdge* deletep = NULL;
             for (V3GraphEdge* edgep = vxp->outBeginp();
                  edgep; edgep = edgep->outNextp()) {
-                if (deletep) {
-                    deletep->unlinkDelete(); deletep = NULL;
-                }
+                if (deletep) VL_DO_CLEAR(deletep->unlinkDelete(), deletep = NULL);
                 // It should be safe to modify the graph, despite using
                 // the GraphPathChecker, as none of the modifications will
                 // change what can be reached from what, nor should they
@@ -162,7 +156,7 @@ public:
                 }
             }
             if (deletep) {
-                deletep->unlinkDelete(); VL_DANGLING(deletep);
+                VL_DO_DANGLING(deletep->unlinkDelete(), deletep);
             }
         }
     }
