@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2005-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2005-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -354,7 +350,7 @@ private:
         for (V3GraphVertex* nextp,*vertexp = m_graphp->verticesBeginp(); vertexp; vertexp=nextp) {
             nextp = vertexp->verticesNextp();
             if (nfaState(vertexp)) {
-                vertexp->unlinkDelete(m_graphp); VL_DANGLING(vertexp);
+                VL_DO_DANGLING(vertexp->unlinkDelete(m_graphp), vertexp);
             }
         }
 
@@ -409,7 +405,7 @@ private:
                 if (vvertexp->accepting()) {
                     for (V3GraphEdge* nextp,*edgep = vertexp->outBeginp(); edgep; edgep=nextp) {
                         nextp = edgep->outNextp();
-                        edgep->unlinkDelete(); VL_DANGLING(edgep);
+                        VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
                     }
                 }
             }
@@ -445,7 +441,7 @@ private:
         for (V3GraphVertex* nextp,*vertexp = m_graphp->verticesBeginp(); vertexp; vertexp=nextp) {
             nextp = vertexp->verticesNextp();
             if (!vertexp->user()) {
-                vertexp->unlinkDelete(m_graphp); VL_DANGLING(vertexp);
+                VL_DO_DANGLING(vertexp->unlinkDelete(m_graphp), vertexp);
             }
         }
     }
@@ -487,7 +483,7 @@ private:
                     }
                 }
                 // Transitions to this state removed by the unlink function
-                vertexp->unlinkDelete(m_graphp); VL_DANGLING(vertexp);
+                VL_DO_DANGLING(vertexp->unlinkDelete(m_graphp), vertexp);
             }
         }
     }
@@ -566,7 +562,7 @@ private:
                             DfaVertex* tovertexp = static_cast<DfaVertex*>(edgep->top());
                             if (tovertexp->accepting()) {
                                 new DfaEdge(graphp(), vvertexp, m_tempNewerReject, vedgep);
-                                edgep->unlinkDelete(); VL_DANGLING(edgep);
+                                VL_DO_DANGLING(edgep->unlinkDelete(), edgep);
                             }
 
                             // NOT of all values goes to accept
@@ -595,10 +591,11 @@ public:
         add_complement_edges();
         if (debug()>=6) m_graphp->dumpDotFilePrefixed("comp_preswap");
 
-        m_tempNewerReject->unlinkDelete(graphp()); m_tempNewerReject = NULL;
+        VL_DO_CLEAR(m_tempNewerReject->unlinkDelete(graphp()), m_tempNewerReject = NULL);
         if (debug()>=6) m_graphp->dumpDotFilePrefixed("comp_out");
     }
     ~DfaGraphComplement() {}
+    VL_UNCOPYABLE(DfaGraphComplement);
 };
 
 void DfaGraph::dfaComplement() {
