@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -89,7 +85,7 @@ class DfaVertex : public V3GraphVertex {
     bool m_accepting;  // Accepting state?
 public:
     // CONSTRUCTORS
-    DfaVertex(DfaGraph* graphp, bool start=false, bool accepting=false)
+    explicit DfaVertex(DfaGraph* graphp, bool start=false, bool accepting=false)
         : V3GraphVertex(graphp)
         , m_start(start), m_accepting(accepting) {}
     using V3GraphVertex::clone;  // We are overriding, not overloading clone(V3Graph*)
