@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Inline's Transformations:
@@ -58,19 +54,21 @@ private:
     //  AstNodeModule::user2()  // CIL_*. Allowed to automatically inline module
     //  AstNodeModule::user3()  // int. Number of cells referencing this module
     //  AstNodeModule::user4()  // int. Statements in module
-    AstUser2InUse       m_inuser2;
-    AstUser3InUse       m_inuser3;
-    AstUser4InUse       m_inuser4;
+    AstUser2InUse m_inuser2;
+    AstUser3InUse m_inuser3;
+    AstUser4InUse m_inuser4;
 
     // For the user2 field:
-    enum {CIL_NOTHARD=0, // Inline not supported
-          CIL_NOTSOFT,   // Don't inline unless user overrides
-          CIL_MAYBE,     // Might inline
-          CIL_USER};     // Pragma suggests inlining
+    enum {
+        CIL_NOTHARD = 0,  // Inline not supported
+        CIL_NOTSOFT,  // Don't inline unless user overrides
+        CIL_MAYBE,  // Might inline
+        CIL_USER
+    };  // Pragma suggests inlining
 
     // STATE
-    AstNodeModule*      m_modp;         // Current module
-    VDouble0            m_statUnsup;    // Statistic tracking
+    AstNodeModule* m_modp;  // Current module
+    VDouble0 m_statUnsup;  // Statistic tracking
 
     typedef std::vector<AstNodeModule*> ModVec;
     ModVec m_allMods;  // All modules, in top-down order.
@@ -87,20 +85,21 @@ private:
     void cantInline(const char* reason, bool hard) {
         if (hard) {
             if (m_modp->user2() != CIL_NOTHARD) {
-                UINFO(4,"  No inline hard: "<<reason<<" "<<m_modp<<endl);
+                UINFO(4, "  No inline hard: " << reason << " " << m_modp << endl);
                 m_modp->user2(CIL_NOTHARD);
                 ++m_statUnsup;
             }
         } else {
             if (m_modp->user2() == CIL_MAYBE) {
-                UINFO(4,"  No inline soft: "<<reason<<" "<<m_modp<<endl);
+                UINFO(4, "  No inline soft: " << reason << " " << m_modp << endl);
                 m_modp->user2(CIL_NOTSOFT);
             }
         }
     }
 
     // VISITORS
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        UASSERT_OBJ(!m_modp, nodep, "Unsupported: Recursive modules");
         m_modp = nodep;
         m_allMods.push_back(nodep);
         m_modp->user2(CIL_MAYBE);
@@ -115,70 +114,73 @@ private:
         iterateChildren(nodep);
         m_modp = NULL;
     }
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         nodep->modp()->user3Inc();  // Inc refs
         m_instances[m_modp][nodep->modp()]++;
         iterateChildren(nodep);
     }
-    virtual void visit(AstPragma* nodep) {
+    virtual void visit(AstPragma* nodep) VL_OVERRIDE {
         if (nodep->pragType() == AstPragmaType::INLINE_MODULE) {
-            //UINFO(0,"PRAG MARK "<<m_modp<<endl);
+            // UINFO(0,"PRAG MARK "<<m_modp<<endl);
             if (!m_modp) {
                 nodep->v3error("Inline pragma not under a module");  // LCOV_EXCL_LINE
             } else if (m_modp->user2() == CIL_MAYBE
                        || m_modp->user2() == CIL_NOTSOFT) {
                 m_modp->user2(CIL_USER);
             }
-            nodep->unlinkFrBack()->deleteTree(); VL_DANGLING(nodep);  // Remove so don't propagate to upper cell...
+            // Remove so don't propagate to upper cell...
+            VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
         } else if (nodep->pragType() == AstPragmaType::NO_INLINE_MODULE) {
             if (!m_modp) {
                 nodep->v3error("Inline pragma not under a module");  // LCOV_EXCL_LINE
             } else {
                 cantInline("Pragma NO_INLINE_MODULE", false);
             }
-            nodep->unlinkFrBack()->deleteTree(); VL_DANGLING(nodep);  // Remove so don't propagate to upper cell...
+            // Remove so don't propagate to upper cell...
+            VL_DO_DANGLING(nodep->unlinkFrBack()->deleteTree(), nodep);
         } else {
             iterateChildren(nodep);
         }
     }
-    virtual void visit(AstVarXRef* nodep) {
+    virtual void visit(AstVarXRef* nodep) VL_OVERRIDE {
         // Cleanup link until V3LinkDot can correct it
         nodep->varp(NULL);
     }
-    virtual void visit(AstNodeFTaskRef* nodep) {
+    virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         // Cleanup link until V3LinkDot can correct it
-        if (!nodep->packagep()) nodep->taskp(NULL);
+        // MethodCalls not currently supported by inliner, so keep linked
+        if (!nodep->packagep() && !VN_IS(nodep, MethodCall)) nodep->taskp(NULL);
         iterateChildren(nodep);
     }
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         m_modp->user4Inc();  // statement count
     }
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         // Don't count assignments, as they'll likely flatten out
         // Still need to iterate though to nullify VarXRefs
         int oldcnt = m_modp->user4();
         iterateChildren(nodep);
         m_modp->user4(oldcnt);
     }
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         // Build user2, user3, and user4 for all modules.
         // Also build m_allMods and m_instances.
         iterateChildren(nodep);
 
         // Iterate through all modules in bottom-up order.
         // Make a final inlining decision for each.
-        for (ModVec::reverse_iterator it=m_allMods.rbegin(); it!=m_allMods.rend(); ++it) {
+        for (ModVec::reverse_iterator it = m_allMods.rbegin(); it != m_allMods.rend(); ++it) {
             AstNodeModule* modp = *it;
 
             // If we're going to inline some modules into this one,
             // update user4 (statement count) to reflect that:
             int statements = modp->user4();
             LocalInstanceMap& localsr = m_instances[modp];
-            for (LocalInstanceMap::iterator it = localsr.begin(); it != localsr.end(); ++it) {
-                AstNodeModule* childp = it->first;
+            for (LocalInstanceMap::iterator iti = localsr.begin(); iti != localsr.end(); ++iti) {
+                AstNodeModule* childp = iti->first;
                 if (childp->user1()) {  // inlining child
-                    statements += (childp->user4() * it->second);
+                    statements += (childp->user4() * iti->second);
                 }
             }
             modp->user4(statements);
@@ -191,20 +193,19 @@ private:
             // If a mod*#refs is < this # nodes, can inline it
             bool doit = ((allowed == CIL_USER)
                          || ((allowed == CIL_MAYBE)
-                             && (refs==1
+                             && (refs == 1
                                  || statements < INLINE_MODS_SMALLER
                                  || v3Global.opt.inlineMult() < 1
-                                 || refs*statements < v3Global.opt.inlineMult())));
+                                 || refs * statements < v3Global.opt.inlineMult())));
             // Packages aren't really "under" anything so they confuse this algorithm
             if (VN_IS(modp, Package)) doit = false;
-            UINFO(4, " Inline="<<doit<<" Possible="<<allowed
-                  <<" Refs="<<refs<<" Stmts="<<statements<<"  "<<modp<<endl);
+            UINFO(4, " Inline=" << doit << " Possible=" << allowed << " Refs=" << refs
+                  << " Stmts=" << statements << "  " << modp << endl);
             modp->user1(doit);
         }
     }
     //--------------------
-    // Default: Just iterate
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         if (m_modp) {
             m_modp->user4Inc();  // Inc statement count
@@ -240,15 +241,13 @@ private:
     VL_DEBUG_FUNC;  // Declare debug()
 
     // VISITORS
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         nodep->user4p(nodep->clonep());
     }
-    // Accelerate
-    virtual void visit(AstNodeStmt* nodep) {}
-    virtual void visit(AstNodeMath* nodep) {}
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    //--------------------
+    virtual void visit(AstNodeStmt*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -270,42 +269,42 @@ private:
     //   See InlineVisitor
 
     // STATE
-    StringSet           m_renamedInterfaces;  // Name of renamed interface variables
-    AstNodeModule*      m_modp;         // Current module
-    AstCell*            m_cellp;        // Cell being cloned
+    StringSet m_renamedInterfaces;  // Name of renamed interface variables
+    AstNodeModule* m_modp;  // Current module
+    AstCell* m_cellp;  // Cell being cloned
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
     // VISITORS
-    virtual void visit(AstCellInline* nodep) {
+    virtual void visit(AstCellInline* nodep) VL_OVERRIDE {
         // Inlined cell under the inline cell, need to move to avoid conflicts
         nodep->unlinkFrBack();
         m_modp->addInlinesp(nodep);
         // Rename
         string name = m_cellp->name() + "__DOT__" + nodep->name();
         nodep->name(name);
-        UINFO(6, "    Inline "<<nodep<<endl);
+        UINFO(6, "    Inline " << nodep << endl);
         // Do CellInlines under this, but don't move them
         iterateChildren(nodep);
     }
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         // Cell under the inline cell, need to rename to avoid conflicts
         string name = m_cellp->name() + "__DOT__" + nodep->name();
         nodep->name(name);
         iterateChildren(nodep);
     }
-    virtual void visit(AstModule* nodep) {
+    virtual void visit(AstModule* nodep) VL_OVERRIDE {
         m_renamedInterfaces.clear();
         iterateChildren(nodep);
     }
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         if (nodep->user2p()) {
             // Make an assignment, so we'll trace it properly
             // user2p is either a const or a var.
-            AstConst*  exprconstp  = VN_CAST(nodep->user2p(), Const);
+            AstConst* exprconstp = VN_CAST(nodep->user2p(), Const);
             AstVarRef* exprvarrefp = VN_CAST(nodep->user2p(), VarRef);
-            UINFO(8,"connectto: "<<nodep->user2p()<<endl);
+            UINFO(8, "connectto: " << nodep->user2p() << endl);
             UASSERT_OBJ(exprconstp || exprvarrefp, nodep,
                         "Unknown interconnect type; pinReconnectSimple should have cleared up");
             if (exprconstp) {
@@ -316,7 +315,7 @@ private:
                 // Public variable at the lower module end - we need to make sure we propagate
                 // the logic changes up and down; if we aliased, we might
                 // remove the change detection on the output variable.
-                UINFO(9,"public pin assign: "<<exprvarrefp<<endl);
+                UINFO(9, "public pin assign: " << exprvarrefp << endl);
                 UASSERT_OBJ(!nodep->isNonOutput(), nodep, "Outputs only - inputs use AssignAlias");
                 m_modp->addStmtp(
                     new AstAssignW(nodep->fileline(),
@@ -326,7 +325,7 @@ private:
                 // Public variable at this end and it is an unpacked array. We need to assign
                 // instead of aliased, because otherwise it will pass V3Slice and invalid
                 // code will be emitted.
-                UINFO(9,"assign to public and unpacked: "<<nodep<<endl);
+                UINFO(9, "assign to public and unpacked: " << nodep << endl);
                 m_modp->addStmtp(
                     new AstAssignW(nodep->fileline(),
                                    new AstVarRef(nodep->fileline(), exprvarrefp->varp(), true),
@@ -338,8 +337,8 @@ private:
                                           new AstVarRef(nodep->fileline(),
                                                         exprvarrefp->varp(), false)));
                 AstNode* nodebp = exprvarrefp->varp();
-                nodep ->fileline()->modifyStateInherit(nodebp->fileline());
-                nodebp->fileline()->modifyStateInherit(nodep ->fileline());
+                nodep->fileline()->modifyStateInherit(nodebp->fileline());
+                nodebp->fileline()->modifyStateInherit(nodep->fileline());
             } else {
                 // Do to inlining child's variable now within the same
                 // module, so a AstVarRef not AstVarXRef below
@@ -349,8 +348,8 @@ private:
                                        new AstVarRef(nodep->fileline(),
                                                      exprvarrefp->varp(), false)));
                 AstNode* nodebp = exprvarrefp->varp();
-                nodep ->fileline()->modifyStateInherit(nodebp->fileline());
-                nodebp->fileline()->modifyStateInherit(nodep ->fileline());
+                nodep->fileline()->modifyStateInherit(nodebp->fileline());
+                nodebp->fileline()->modifyStateInherit(nodep->fileline());
             }
         }
         // Iterate won't hit AstIfaceRefDType directly as it is no longer underneath the module
@@ -379,42 +378,40 @@ private:
         string name = m_cellp->name() + "__DOT__" + nodep->name();
         if (!nodep->isFuncLocal()) nodep->inlineAttrReset(name);
         if (!m_cellp->isTrace()) nodep->trace(false);
-        if (debug()>=9) { nodep->dumpTree(cout, "varchanged:"); }
-        if (debug()>=9 && nodep->valuep()) { nodep->valuep()->dumpTree(cout, "varchangei:"); }
+        if (debug() >= 9) { nodep->dumpTree(cout, "varchanged:"); }
+        if (debug() >= 9 && nodep->valuep()) { nodep->valuep()->dumpTree(cout, "varchangei:"); }
         iterateChildren(nodep);
     }
-    virtual void visit(AstNodeFTask* nodep) {
+    virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
         // Function under the inline cell, need to rename to avoid conflicts
         nodep->name(m_cellp->name() + "__DOT__" + nodep->name());
         iterateChildren(nodep);
     }
-    virtual void visit(AstTypedef* nodep) {
+    virtual void visit(AstTypedef* nodep) VL_OVERRIDE {
         // Typedef under the inline cell, need to rename to avoid conflicts
         nodep->name(m_cellp->name() + "__DOT__" + nodep->name());
         iterateChildren(nodep);
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (nodep->varp()->user2p()  // It's being converted to an alias.
             && !nodep->varp()->user3()
             && !VN_IS(nodep->backp(), AssignAlias)) {  // Don't constant propagate aliases (we just made)
-            AstConst*  exprconstp  = VN_CAST(nodep->varp()->user2p(), Const);
+            AstConst* exprconstp = VN_CAST(nodep->varp()->user2p(), Const);
             AstVarRef* exprvarrefp = VN_CAST(nodep->varp()->user2p(), VarRef);
             if (exprconstp) {
                 nodep->replaceWith(exprconstp->cloneTree(true));
-                nodep->deleteTree(); VL_DANGLING(nodep);
+                VL_DO_DANGLING(nodep->deleteTree(), nodep);
                 return;
-            }
-            else if (exprvarrefp) {
-                nodep->varp( exprvarrefp->varp() );
-            }
-            else {
+            } else if (exprvarrefp) {
+                nodep->varp(exprvarrefp->varp());
+            } else {
                 nodep->v3fatalSrc("Null connection?");
             }
         }
         nodep->name(nodep->varp()->name());
         iterateChildren(nodep);
     }
-    virtual void visit(AstVarXRef* nodep) {
+    virtual void visit(AstVarXRef* nodep) VL_OVERRIDE {
         // Track what scope it was originally under so V3LinkDot can resolve it
         string newdots = VString::dot(m_cellp->name(), ".", nodep->inlinedDots());
         nodep->inlinedDots(newdots);
@@ -425,7 +422,7 @@ private:
             }
             // If foo.bar, and foo is an interface, then need to search again for foo
             string::size_type pos = tryname.rfind('.');
-            if (pos == string::npos || pos==0) {
+            if (pos == string::npos || pos == 0) {
                 break;
             } else {
                 tryname = tryname.substr(0, pos);
@@ -433,42 +430,40 @@ private:
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstNodeFTaskRef* nodep) {
+    virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         // Track what scope it was originally under so V3LinkDot can resolve it
         string newdots = VString::dot(m_cellp->name(), ".", nodep->inlinedDots());
         nodep->inlinedDots(newdots);
         if (m_renamedInterfaces.count(nodep->dotted())) {
             nodep->dotted(m_cellp->name() + "__DOT__" + nodep->dotted());
         }
-        UINFO(8,"   "<<nodep<<endl);
+        UINFO(8, "   " << nodep << endl);
         iterateChildren(nodep);
     }
 
     // Not needed, as V3LinkDot doesn't care about typedefs
-    //virtual void visit(AstRefDType* nodep) {}
+    // virtual void visit(AstRefDType* nodep) VL_OVERRIDE {}
 
-    virtual void visit(AstScopeName* nodep) {
+    virtual void visit(AstScopeName* nodep) VL_OVERRIDE {
         // If there's a %m in the display text, we add a special node that will contain the name()
         // Similar code in V3Begin
         // To keep correct visual order, must add before other Text's
         AstNode* afterp = nodep->scopeAttrp();
         if (afterp) afterp->unlinkFrBackWithNext();
-        nodep->scopeAttrp(new AstText(nodep->fileline(), string("__DOT__")+m_cellp->name()));
+        nodep->scopeAttrp(new AstText(nodep->fileline(), string("__DOT__") + m_cellp->name()));
         if (afterp) nodep->scopeAttrp(afterp);
         afterp = nodep->scopeEntrp();
         if (afterp) afterp->unlinkFrBackWithNext();
-        nodep->scopeEntrp(new AstText(nodep->fileline(), string("__DOT__")+m_cellp->name()));
+        nodep->scopeEntrp(new AstText(nodep->fileline(), string("__DOT__") + m_cellp->name()));
         if (afterp) nodep->scopeEntrp(afterp);
         iterateChildren(nodep);
     }
-    virtual void visit(AstCoverDecl* nodep) {
+    virtual void visit(AstCoverDecl* nodep) VL_OVERRIDE {
         // Fix path in coverage statements
         nodep->hier(VString::dot(m_cellp->prettyName(), ".", nodep->hier()));
         iterateChildren(nodep);
     }
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -490,31 +485,31 @@ private:
     //  AstIfaceRefDType::user5p()  // Whether the cell pointed to by this
     //                              // AstIfaceRefDType has been inlined
     //  Input:
-    //   AstNodeModule::user1p()        // bool. True to inline this module (from InlineMarkVisitor)
+    //   AstNodeModule::user1p()    // bool. True to inline this module (from InlineMarkVisitor)
     // Cleared each cell
     //   AstVar::user2p()       // AstVarRef*/AstConst*  Points to signal this
     //                          // is a direct connect to
     //   AstVar::user3()        // bool    Don't alias the user2, keep it as signal
     //   AstCell::user4         // AstCell* of the created clone
 
-    AstUser2InUse       m_inuser2;
-    AstUser3InUse       m_inuser3;
-    AstUser4InUse       m_inuser4;
-    AstUser5InUse       m_inuser5;
+    AstUser2InUse m_inuser2;
+    AstUser3InUse m_inuser3;
+    AstUser4InUse m_inuser4;
+    AstUser5InUse m_inuser5;
 
     // STATE
-    AstNodeModule*      m_modp;         // Current module
-    VDouble0            m_statCells;    // Statistic tracking
+    AstNodeModule* m_modp;  // Current module
+    VDouble0 m_statCells;  // Statistic tracking
 
     // METHODS
     VL_DEBUG_FUNC;  // Declare debug()
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         // Iterate modules backwards, in bottom-up order.  Required!
         iterateChildrenBackwards(nodep);
     }
-    virtual void visit(AstIfaceRefDType* nodep) {
+    virtual void visit(AstIfaceRefDType* nodep) VL_OVERRIDE {
         if (nodep->user5()) {
             // The cell has been removed so let's make sure we don't leave a reference to it
             // This dtype may still be in use by the AstAssignVarScope created earlier
@@ -522,42 +517,46 @@ private:
             nodep->cellp(NULL);
         }
     }
-    virtual void visit(AstNodeModule* nodep) {
-        m_modp = nodep;
-        iterateChildren(nodep);
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        AstNodeModule* origModp = m_modp;
+        {
+            m_modp = nodep;
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
     }
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         if (nodep->modp()->user1()) {  // Marked with inline request
-            UINFO(5," Inline CELL   "<<nodep<<endl);
-            UINFO(5,"   To MOD      "<<m_modp<<endl);
+            UINFO(5, " Inline CELL   " << nodep << endl);
+            UINFO(5, "   To MOD      " << m_modp << endl);
             ++m_statCells;
 
             // Before cloning simplify pin assignments
             // Better off before, as if module has multiple instantiations
             // we'll save work, and we can't call pinReconnectSimple in
             // this loop as it clone()s itself.
-            for (AstPin* pinp = nodep->pinsp(); pinp; pinp=VN_CAST(pinp->nextp(), Pin)) {
+            for (AstPin* pinp = nodep->pinsp(); pinp; pinp = VN_CAST(pinp->nextp(), Pin)) {
                 if (!pinp->exprp()) continue;
                 V3Inst::pinReconnectSimple(pinp, nodep, false);
             }
 
             // Clone original module
-            if (debug()>=9) { nodep->dumpTree(cout, "inlcell:"); }
-            //if (debug()>=9) { nodep->modp()->dumpTree(cout,"oldmod:"); }
+            if (debug() >= 9) { nodep->dumpTree(cout, "inlcell:"); }
+            // if (debug()>=9) { nodep->modp()->dumpTree(cout,"oldmod:"); }
             AstNodeModule* newmodp = nodep->modp()->cloneTree(false);
-            if (debug()>=9) { newmodp->dumpTree(cout, "newmod:"); }
+            if (debug() >= 9) { newmodp->dumpTree(cout, "newmod:"); }
             // Clear var markings and find cell cross references
             AstNode::user2ClearTree();
             AstNode::user4ClearTree();
             { InlineCollectVisitor(nodep->modp()); }  // {} to destroy visitor immediately
             // Create data for dotted variable resolution
-            AstCellInline* inlinep = new AstCellInline(nodep->fileline(),
-                                                       nodep->name(), nodep->modp()->origName());
+            AstCellInline* inlinep
+                = new AstCellInline(nodep->fileline(), nodep->name(), nodep->modp()->origName());
             m_modp->addInlinesp(inlinep);  // Must be parsed before any AstCells
             // Create assignments to the pins
-            for (AstPin* pinp = nodep->pinsp(); pinp; pinp=VN_CAST(pinp->nextp(), Pin)) {
+            for (AstPin* pinp = nodep->pinsp(); pinp; pinp = VN_CAST(pinp->nextp(), Pin)) {
                 if (!pinp->exprp()) continue;
-                UINFO(6,"     Pin change from "<<pinp->modVarp()<<endl);
+                UINFO(6, "     Pin change from " << pinp->modVarp() << endl);
                 // Make new signal; even though we'll optimize the interconnect, we
                 // need an alias to trace correctly.  If tracing is disabled, we'll
                 // delete it in later optimizations.
@@ -579,37 +578,35 @@ private:
                 // One to one interconnect won't make a temporary variable.
                 // This prevents creating a lot of extra wires for clock signals.
                 // It will become a tracing alias.
-                UINFO(6,"One-to-one "<<connectRefp<<endl);
-                UINFO(6,"       -to "<<pinNewVarp<<endl);
+                UINFO(6, "One-to-one " << connectRefp << endl);
+                UINFO(6, "       -to " << pinNewVarp << endl);
                 pinNewVarp->user2p(connectRefp);
                 // Public output inside the cell must go via an assign rather
                 // than alias.  Else the public logic will set the alias, losing
                 // the value to be propagated up (InOnly isn't a problem as the
                 // AssignAlias will create the assignment for us)
                 pinNewVarp->user3(pinNewVarp->isSigUserRWPublic()
-                                  && pinNewVarp->direction()==VDirection::OUTPUT);
+                                  && pinNewVarp->direction() == VDirection::OUTPUT);
             }
             // Cleanup var names, etc, to not conflict
             { InlineRelinkVisitor(newmodp, m_modp, nodep); }
             // Move statements to top module
-            if (debug()>=9) { newmodp->dumpTree(cout, "fixmod:"); }
+            if (debug() >= 9) { newmodp->dumpTree(cout, "fixmod:"); }
             AstNode* stmtsp = newmodp->stmtsp();
             if (stmtsp) stmtsp->unlinkFrBackWithNext();
             if (stmtsp) m_modp->addStmtp(stmtsp);
             // Remove the cell
-            newmodp->deleteTree(); VL_DANGLING(newmodp);  // Clear any leftover ports, etc
+            VL_DO_DANGLING(newmodp->deleteTree(), newmodp);  // Clear any leftover ports, etc
             nodep->unlinkFrBack();
-            pushDeletep(nodep); VL_DANGLING(nodep);
-            if (debug()>=9) { m_modp->dumpTree(cout, "donemod:"); }
+            VL_DO_DANGLING(pushDeletep(nodep), nodep);
+            if (debug() >= 9) { m_modp->dumpTree(cout, "donemod:"); }
         }
     }
 
     //--------------------
-    virtual void visit(AstNodeMath* nodep) {}  // Accelerate
-    virtual void visit(AstNodeStmt* nodep) {}  // Accelerate
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeStmt*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -638,17 +635,11 @@ private:
     VL_DEBUG_FUNC;  // Declare debug()
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
-        iterateChildren(nodep);
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+    virtual void visit(AstModule* nodep) VL_OVERRIDE {
+        if (nodep->isTop()) { iterateChildren(nodep); }
     }
-
-    virtual void visit(AstModule* nodep) {
-        if (nodep->isTop()) {
-            iterateChildren(nodep);
-        }
-    }
-
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         string oldScope = m_scope;
         if (m_scope.empty()) {
             m_scope = nodep->name();
@@ -658,7 +649,7 @@ private:
 
         if (AstModule* modp = VN_CAST(nodep->modp(), Module)) {
             // Pass Cell pointers down to the next module
-            for (AstPin* pinp = nodep->pinsp(); pinp; pinp=VN_CAST(pinp->nextp(), Pin)) {
+            for (AstPin* pinp = nodep->pinsp(); pinp; pinp = VN_CAST(pinp->nextp(), Pin)) {
                 AstVar* varp = pinp->modVarp();
                 AstVarRef* varrefp = VN_CAST(pinp->exprp(), VarRef);
                 if (!varrefp) continue;
@@ -683,8 +674,7 @@ private:
 
         m_scope = oldScope;
     }
-
-    virtual void visit(AstAssignVarScope* nodep) {
+    virtual void visit(AstAssignVarScope* nodep) VL_OVERRIDE {
         // Reference
         AstVarRef* reflp = VN_CAST(nodep->lhsp(), VarRef);
         // What the reference refers to
@@ -708,49 +698,37 @@ private:
         alias += varlp->name();
         cellp->addIntfRefp(new AstIntfRef(varlp->fileline(), alias));
     }
-
     //--------------------
-    virtual void visit(AstNodeMath*) {}  // Accelerate
-    virtual void visit(AstNodeStmt*) {}  // Accelerate
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeStmt*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
-    explicit InlineIntfRefVisitor(AstNode* nodep) {
-        iterate(nodep);
-    }
-    virtual ~InlineIntfRefVisitor() {
-    }
+    explicit InlineIntfRefVisitor(AstNode* nodep) { iterate(nodep); }
+    virtual ~InlineIntfRefVisitor() {}
 };
 
 //######################################################################
 // Inline class functions
 
 void V3Inline::inlineAll(AstNetlist* nodep) {
-    UINFO(2,__FUNCTION__<<": "<<endl);
+    UINFO(2, __FUNCTION__ << ": " << endl);
     AstUser1InUse m_inuser1;  // output of InlineMarkVisitor,
                               // input to InlineVisitor.
-    {
-        // Scoped to clean up temp userN's
-        InlineMarkVisitor mvisitor (nodep);
-    }
-    {
-        InlineVisitor visitor (nodep);
-    }
+    // Scoped to clean up temp userN's
+    { InlineMarkVisitor mvisitor(nodep); }
+    { InlineVisitor visitor(nodep); }
     // Remove all modules that were inlined
     // V3Dead will also clean them up, but if we have debug on, it's a good
     // idea to avoid dumping the hugely exploded tree.
     AstNodeModule* nextmodp;
-    for (AstNodeModule* modp = v3Global.rootp()->modulesp(); modp; modp=nextmodp) {
+    for (AstNodeModule* modp = v3Global.rootp()->modulesp(); modp; modp = nextmodp) {
         nextmodp = VN_CAST(modp->nextp(), NodeModule);
         if (modp->user1()) {  // Was inlined
-            modp->unlinkFrBack()->deleteTree(); VL_DANGLING(modp);
+            VL_DO_DANGLING(modp->unlinkFrBack()->deleteTree(), modp);
         }
     }
-    {
-        InlineIntfRefVisitor crvisitor (nodep);
-    }
+    { InlineIntfRefVisitor crvisitor(nodep); }
     V3Global::dumpCheckGlobalTree("inline", 0, v3Global.opt.dumpTreeLevel(__FILE__) >= 3);
 }
