@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // LIFE TRANSFORMATIONS:
@@ -158,7 +154,7 @@ public:
                 // above our current iteration point.
                 if (debug()>4) oldassp->dumpTree(cout, "       REMOVE/SAMEBLK ");
                 entp->complexAssign();
-                m_statep->pushUnlinkDeletep(oldassp); VL_DANGLING(oldassp);
+                VL_DO_DANGLING(m_statep->pushUnlinkDeletep(oldassp), oldassp);
                 ++m_statep->m_statAssnDel;
             }
         }
@@ -195,7 +191,7 @@ public:
                     // We'll later constant propagate
                     UINFO(4,"     replaceconst: "<<varrefp<<endl);
                     varrefp->replaceWith(constp->cloneTree(false));
-                    varrefp->deleteTree(); VL_DANGLING(varrefp);
+                    VL_DO_DANGLING(varrefp->deleteTree(), varrefp);
                     ++m_statep->m_statAssnCon;
                     return;  // **DONE, no longer a var reference**
                 }
@@ -296,7 +292,7 @@ private:
     VL_DEBUG_FUNC;  // Declare debug()
 
     // VISITORS
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         // Consumption/generation of a variable,
         // it's used so can't elim assignment before this use.
         UASSERT_OBJ(nodep->varScopep(), nodep, "NULL");
@@ -307,10 +303,10 @@ private:
             m_sideEffect = true;  // $sscanf etc may have RHS vars that are lvalues
             m_lifep->complexAssign(vscp);
         } else {
-            m_lifep->varUsageReplace(vscp, nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(m_lifep->varUsageReplace(vscp, nodep), nodep);
         }
     }
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         // Collect any used variables first, as lhs may also be on rhs
         // Similar code in V3Dead
         vluint64_t lastEdit = AstNode::editCountGbl();  // When it was last edited
@@ -330,13 +326,13 @@ private:
             iterateAndNextNull(nodep->lhsp());
         }
     }
-    virtual void visit(AstAssignDly* nodep) {
+    virtual void visit(AstAssignDly* nodep) VL_OVERRIDE {
         // Don't treat as normal assign; V3Life doesn't understand time sense
         iterateChildren(nodep);
     }
 
     //---- Track control flow changes
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         UINFO(4,"   IF "<<nodep<<endl);
         // Condition is part of PREVIOUS block
         iterateAndNextNull(nodep->condp());
@@ -358,11 +354,11 @@ private:
         // For the next assignments, clear any variables that were read or written in the block
         ifLifep->lifeToAbove();
         elseLifep->lifeToAbove();
-        delete ifLifep;
-        delete elseLifep;
+        VL_DO_DANGLING(delete ifLifep, ifLifep);
+        VL_DO_DANGLING(delete elseLifep, elseLifep);
     }
 
-    virtual void visit(AstWhile* nodep) {
+    virtual void visit(AstWhile* nodep) VL_OVERRIDE {
         // While's are a problem, as we don't allow loops in the graph.  We
         // may go around the cond/body multiple times.  Thus a
         // lifelication just in the body is ok, but we can't delete an
@@ -388,10 +384,10 @@ private:
         // For the next assignments, clear any variables that were read or written in the block
         condLifep->lifeToAbove();
         bodyLifep->lifeToAbove();
-        delete condLifep;
-        delete bodyLifep;
+        VL_DO_DANGLING(delete condLifep, condLifep);
+        VL_DO_DANGLING(delete bodyLifep, bodyLifep);
     }
-    virtual void visit(AstJumpLabel* nodep) {
+    virtual void visit(AstJumpLabel* nodep) VL_OVERRIDE {
         // As with While's we can't predict if a JumpGo will kill us or not
         // It's worse though as an IF(..., JUMPGO) may change the control flow.
         // Just don't optimize blocks with labels; they're rare - so far.
@@ -408,9 +404,9 @@ private:
         UINFO(4,"   joinjump"<<endl);
         // For the next assignments, clear any variables that were read or written in the block
         bodyLifep->lifeToAbove();
-        delete bodyLifep;
+        VL_DO_DANGLING(delete bodyLifep, bodyLifep);
     }
-    virtual void visit(AstCCall* nodep) {
+    virtual void visit(AstNodeCCall* nodep) VL_OVERRIDE {
         //UINFO(4,"  CCALL "<<nodep<<endl);
         iterateChildren(nodep);
         // Enter the function and trace it
@@ -419,8 +415,8 @@ private:
             iterate(nodep->funcp());
         }
     }
-    virtual void visit(AstCFunc* nodep) {
-        //UINFO(4,"  CCALL "<<nodep<<endl);
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
+        //UINFO(4,"  CFUNC "<<nodep<<endl);
         if (!m_tracingCall && !nodep->entryPoint()) return;
         m_tracingCall = false;
         if (nodep->dpiImport() && !nodep->pure()) {
@@ -428,19 +424,17 @@ private:
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstUCFunc* nodep) {
+    virtual void visit(AstUCFunc* nodep) VL_OVERRIDE {
         m_sideEffect = true;  // If appears on assign RHS, don't ever delete the assignment
         iterateChildren(nodep);
     }
-    virtual void visit(AstCMath* nodep) {
+    virtual void visit(AstCMath* nodep) VL_OVERRIDE {
         m_sideEffect = true;  // If appears on assign RHS, don't ever delete the assignment
         iterateChildren(nodep);
     }
 
-    virtual void visit(AstVar*) {}  // Don't want varrefs under it
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstVar*) VL_OVERRIDE {}  // Don't want varrefs under it
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -453,11 +447,11 @@ public:
         {
             m_lifep = new LifeBlock(NULL, m_statep);
             iterate(nodep);
-            if (m_lifep) { delete m_lifep; m_lifep = NULL; }
+            if (m_lifep) VL_DO_CLEAR(delete m_lifep, m_lifep = NULL);
         }
     }
     virtual ~LifeVisitor() {
-        if (m_lifep) { delete m_lifep; m_lifep = NULL; }
+        if (m_lifep) VL_DO_CLEAR(delete m_lifep, m_lifep = NULL);
     }
     VL_UNCOPYABLE(LifeVisitor);
 };
@@ -472,30 +466,29 @@ private:
     LifeState* m_statep;        // Current state
 
     // VISITORS
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         if (nodep->entryPoint()) {
             // Usage model 1: Simulate all C code, doing lifetime analysis
             LifeVisitor visitor (nodep, m_statep);
         }
     }
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         // Usage model 2: Cleanup basic blocks
         LifeVisitor visitor (nodep, m_statep);
     }
-    virtual void visit(AstInitial* nodep) {
+    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
         // Usage model 2: Cleanup basic blocks
         LifeVisitor visitor (nodep, m_statep);
     }
-    virtual void visit(AstFinal* nodep) {
+    virtual void visit(AstFinal* nodep) VL_OVERRIDE {
         // Usage model 2: Cleanup basic blocks
         LifeVisitor visitor (nodep, m_statep);
     }
-    virtual void visit(AstVar*) {}  // Accelerate
-    virtual void visit(AstNodeStmt*) {}  // Accelerate
-    virtual void visit(AstNodeMath*) {}  // Accelerate
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstVar*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeStmt*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     LifeTopVisitor(AstNetlist* nodep, LifeState* statep) {
