@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // NO EDITS: Don't replace or delete nodes, as the parser symbol table
@@ -158,7 +154,7 @@ private:
     }
 
     // VISITs
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         AstNode::user1ClearTree();
         readModNames();
         iterateChildren(nodep);
@@ -190,45 +186,49 @@ private:
             v3error("Specified --top-module '"<<v3Global.opt.topModule()<<"' was not found in design.");
         }
     }
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         // Module: Pick up modnames, so we can resolve cells later
-        m_modp = nodep;
-        UINFO(2,"Link Module: "<<nodep<<endl);
-        if (nodep->fileline()->filebasenameNoExt() != nodep->prettyName()
-            && !v3Global.opt.isLibraryFile(nodep->fileline()->filename())
-            && !nodep->recursiveClone()
-            && !nodep->internal()) {
-            // We only complain once per file, otherwise library-like files
-            // have a huge mess of warnings
-            if (m_declfnWarned.find(nodep->fileline()->filename()) == m_declfnWarned.end()) {
-                m_declfnWarned.insert(nodep->fileline()->filename());
-                nodep->v3warn(DECLFILENAME, "Filename '"<<nodep->fileline()->filebasenameNoExt()
-                              <<"' does not match "<<nodep->typeName()
-                              <<" name: "<<nodep->prettyNameQ());
+        AstNodeModule* oldModp = m_modp;
+        {
+            m_modp = nodep;
+            UINFO(2, "Link Module: " << nodep << endl);
+            if (nodep->fileline()->filebasenameNoExt() != nodep->prettyName()
+                && !v3Global.opt.isLibraryFile(nodep->fileline()->filename())
+                && !nodep->recursiveClone() && !nodep->internal()) {
+                // We only complain once per file, otherwise library-like files
+                // have a huge mess of warnings
+                if (m_declfnWarned.find(nodep->fileline()->filename()) == m_declfnWarned.end()) {
+                    m_declfnWarned.insert(nodep->fileline()->filename());
+                    nodep->v3warn(DECLFILENAME, "Filename '"
+                                  << nodep->fileline()->filebasenameNoExt()
+                                  << "' does not match " << nodep->typeName()
+                                  << " name: " << nodep->prettyNameQ());
+                }
             }
+            if (VN_IS(nodep, Iface) || VN_IS(nodep, Package)) {
+                nodep->inLibrary(true);  // Interfaces can't be at top, unless asked
+            }
+            bool topMatch = (v3Global.opt.topModule() == nodep->prettyName());
+            if (topMatch) {
+                m_topVertexp = vertex(nodep);
+                UINFO(2, "Link --top-module: " << nodep << endl);
+                nodep->inLibrary(false);  // Safer to make sure it doesn't disappear
+            }
+            if (v3Global.opt.topModule() == "" ? nodep->inLibrary()  // Library cells are lower
+                : !topMatch) {  // Any non-specified module is lower
+                // Put under a fake vertex so that the graph ranking won't indicate
+                // this is a top level module
+                if (!m_libVertexp) m_libVertexp = new LibraryVertex(&m_graph);
+                new V3GraphEdge(&m_graph, m_libVertexp, vertex(nodep), 1, false);
+            }
+            // Note AstBind also has iteration on cells
+            iterateChildren(nodep);
+            nodep->checkTree();
         }
-        if (VN_IS(nodep, Iface) || VN_IS(nodep, Package)) nodep->inLibrary(true);  // Interfaces can't be at top, unless asked
-        bool topMatch = (v3Global.opt.topModule()==nodep->prettyName());
-        if (topMatch) {
-            m_topVertexp = vertex(nodep);
-            UINFO(2,"Link --top-module: "<<nodep<<endl);
-            nodep->inLibrary(false);  // Safer to make sure it doesn't disappear
-        }
-        if (v3Global.opt.topModule()==""
-            ? nodep->inLibrary()  // Library cells are lower
-            : !topMatch) {  // Any non-specified module is lower
-            // Put under a fake vertex so that the graph ranking won't indicate
-            // this is a top level module
-            if (!m_libVertexp) m_libVertexp = new LibraryVertex(&m_graph);
-            new V3GraphEdge(&m_graph, m_libVertexp, vertex(nodep), 1, false);
-        }
-        // Note AstBind also has iteration on cells
-        iterateChildren(nodep);
-        nodep->checkTree();
-        m_modp = NULL;
+        m_modp = oldModp;
     }
 
-    virtual void visit(AstIfaceRefDType* nodep) {
+    virtual void visit(AstIfaceRefDType* nodep) VL_OVERRIDE {
         // Cell: Resolve its filename.  If necessary, parse it.
         UINFO(4,"Link IfaceRef: "<<nodep<<endl);
         // Use findIdUpward instead of findIdFlat; it doesn't matter for now
@@ -247,14 +247,14 @@ private:
         // Note cannot do modport resolution here; modports are allowed underneath generates
     }
 
-    virtual void visit(AstPackageImport* nodep) {
+    virtual void visit(AstPackageImport* nodep) VL_OVERRIDE {
         // Package Import: We need to do the package before the use of a package
         iterateChildren(nodep);
         UASSERT_OBJ(nodep->packagep(), nodep, "Unlinked package");  // Parser should set packagep
         new V3GraphEdge(&m_graph, vertex(m_modp), vertex(nodep->packagep()), 1, false);
     }
 
-    virtual void visit(AstBind* nodep) {
+    virtual void visit(AstBind* nodep) VL_OVERRIDE {
         // Bind: Has cells underneath that need to be put into the new
         // module, and cells which need resolution
         // TODO this doesn't allow bind to dotted hier names, that would require
@@ -276,7 +276,7 @@ private:
         pushDeletep(nodep->unlinkFrBack());
     }
 
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         // Cell: Resolve its filename.  If necessary, parse it.
         // Execute only once.  Complication is that cloning may result in
         // user1 being set (for pre-clone) so check if user1() matches the
@@ -354,7 +354,7 @@ private:
                 if (pinStar) pinp->v3error("Duplicate .* in a cell");
                 pinStar = true;
                 // Done with this fake pin
-                pinp->unlinkFrBack()->deleteTree(); VL_DANGLING(pinp);
+                VL_DO_DANGLING(pinp->unlinkFrBack()->deleteTree(), pinp);
             }
         }
         // Convert unnamed pins to pin number based assignments
@@ -381,9 +381,7 @@ private:
                                      <<pinp->prettyNameQ());
                     }
                 }
-                if (ports.find(pinp->name()) == ports.end()) {
-                    ports.insert(pinp->name());
-                }
+                ports.insert(pinp->name());
             }
             // We search ports, rather than in/out declarations as they aren't resolved yet,
             // and it's easier to do it now than in V3LinkDot when we'd need to repeat steps.
@@ -448,11 +446,8 @@ private:
 
     // Accelerate the recursion
     // Must do statements to support Generates, math though...
-    virtual void visit(AstNodeMath* nodep) {}
-    virtual void visit(AstNode* nodep) {
-        // Default: Just iterate
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
     // METHODS
     void readModNames() {
@@ -470,7 +465,7 @@ private:
                                   <<foundp->warnContextSecondary());
                 }
                 nodep->unlinkFrBack();
-                pushDeletep(nodep); VL_DANGLING(nodep);
+                VL_DO_DANGLING(pushDeletep(nodep), nodep);
             } else if (!foundp) {
                 m_mods.rootp()->insert(nodep->name(), new VSymEnt(&m_mods, nodep));
             }
