@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // LinkLValue TRANSFORMATIONS:
@@ -50,7 +46,7 @@ private:
 
     // VISITs
     // Result handing
-    virtual void visit(AstNodeVarRef* nodep) {
+    virtual void visit(AstNodeVarRef* nodep) VL_OVERRIDE {
         // VarRef: LValue its reference
         if (m_setRefLvalue) {
             nodep->lvalue(true);
@@ -66,7 +62,7 @@ private:
     }
 
     // Nodes that start propagating down lvalues
-    virtual void visit(AstPin* nodep) {
+    virtual void visit(AstPin* nodep) VL_OVERRIDE {
         if (nodep->modVarp() && nodep->modVarp()->isWritable()) {
             // When the varref's were created, we didn't know the I/O state
             // Now that we do, and it's from a output, we know it's a lvalue
@@ -77,7 +73,7 @@ private:
             iterateChildren(nodep);
         }
     }
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -87,7 +83,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstFOpen* nodep) {
+    virtual void visit(AstFOpen* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -98,7 +94,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstFClose* nodep) {
+    virtual void visit(AstFClose* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -106,7 +102,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstFFlush* nodep) {
+    virtual void visit(AstFFlush* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -114,7 +110,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstFGetC* nodep) {
+    virtual void visit(AstFGetC* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -122,7 +118,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstFGetS* nodep) {
+    virtual void visit(AstFGetS* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -131,7 +127,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstFRead* nodep) {
+    virtual void visit(AstFRead* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -140,7 +136,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstFScanF* nodep) {
+    virtual void visit(AstFScanF* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -149,7 +145,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstFUngetC* nodep) {
+    virtual void visit(AstFUngetC* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -157,7 +153,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstSScanF* nodep) {
+    virtual void visit(AstSScanF* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -165,13 +161,13 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstSysIgnore* nodep) {
+    virtual void visit(AstSysIgnore* nodep) VL_OVERRIDE {
         // Can't know if lvalue or not; presume so as stricter
         bool last_setRefLvalue = m_setRefLvalue;
         iterateChildren(nodep);
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstReadMem* nodep) {
+    virtual void visit(AstReadMem* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -183,7 +179,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstValuePlusArgs* nodep) {
+    virtual void visit(AstValuePlusArgs* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = false;
@@ -193,7 +189,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstSFormat* nodep) {
+    virtual void visit(AstSFormat* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             m_setRefLvalue = true;
@@ -205,7 +201,7 @@ private:
     }
 
     // Nodes that change LValue state
-    virtual void visit(AstSel* nodep) {
+    virtual void visit(AstSel* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {
             iterateAndNextNull(nodep->lhsp());
@@ -216,7 +212,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstNodeSel* nodep) {
+    virtual void visit(AstNodeSel* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {   // Only set lvalues on the from
             iterateAndNextNull(nodep->lhsp());
@@ -225,7 +221,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstCellArrayRef* nodep) {
+    virtual void visit(AstCellArrayRef* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {   // selp is not an lvalue
             m_setRefLvalue = false;
@@ -233,7 +229,7 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstNodePreSel* nodep) {
+    virtual void visit(AstNodePreSel* nodep) VL_OVERRIDE {
         bool last_setRefLvalue = m_setRefLvalue;
         {   // Only set lvalues on the from
             iterateAndNextNull(nodep->lhsp());
@@ -243,12 +239,12 @@ private:
         }
         m_setRefLvalue = last_setRefLvalue;
     }
-    virtual void visit(AstNodeFTask* nodep) {
+    virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
         m_ftaskp = nodep;
         iterateChildren(nodep);
         m_ftaskp = NULL;
     }
-    virtual void visit(AstNodeFTaskRef* nodep) {
+    virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         AstNode* pinp = nodep->pinsp();
         AstNodeFTask* taskp = nodep->taskp();
         // We'll deal with mismatching pins later
@@ -270,10 +266,7 @@ private:
         }
     }
 
-    virtual void visit(AstNode* nodep) {
-        // Default: Just iterate
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
