@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // LinkResolve TRANSFORMATIONS:
@@ -49,12 +45,12 @@ private:
     // NODE STATE
     //  Entire netlist:
     //   AstCaseItem::user2()   // bool           Moved default caseitems
-    AstUser2InUse       m_inuser2;
+    AstUser2InUse m_inuser2;
 
     // STATE
     // Below state needs to be preserved between each module call.
-    AstNodeModule*      m_modp;         // Current module
-    AstNodeFTask* m_ftaskp;     // Function or task we're inside
+    AstNodeModule* m_modp;  // Current module
+    AstNodeFTask* m_ftaskp;  // Function or task we're inside
     AstNodeCoverOrAssert* m_assertp;  // Current assertion
     int m_senitemCvtNum;  // Temporary signal counter
 
@@ -65,31 +61,36 @@ private:
     // TODO: Most of these visitors are here for historical reasons.
     // TODO: ExpectDecriptor can move to data type resolution, and the rest
     // TODO: could move to V3LinkParse to get them out of the way of elaboration
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         // Module: Create sim table for entire module and iterate
         UINFO(8,"MODULE "<<nodep<<endl);
         if (nodep->dead()) return;
-        m_modp = nodep;
-        m_senitemCvtNum = 0;
-        iterateChildren(nodep);
-        m_modp = NULL;
+        AstNodeModule* origModp = m_modp;
+        int origSenitemCvtNum = m_senitemCvtNum;
+        {
+            m_modp = nodep;
+            m_senitemCvtNum = 0;
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
+        m_senitemCvtNum = origSenitemCvtNum;
     }
-    virtual void visit(AstInitial* nodep) {
+    virtual void visit(AstInitial* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         // Initial assignments under function/tasks can just be simple
         // assignments without the initial
         if (m_ftaskp) {
-            nodep->replaceWith(nodep->bodysp()->unlinkFrBackWithNext()); VL_DANGLING(nodep);
+            VL_DO_DANGLING(nodep->replaceWith(nodep->bodysp()->unlinkFrBackWithNext()), nodep);
         }
     }
-    virtual void visit(AstNodeCoverOrAssert* nodep) {
+    virtual void visit(AstNodeCoverOrAssert* nodep) VL_OVERRIDE {
         if (m_assertp) nodep->v3error("Assert not allowed under another assert");
         m_assertp = nodep;
         iterateChildren(nodep);
         m_assertp = NULL;
     }
 
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         if (m_ftaskp) nodep->funcLocal(true);
         if (nodep->isSigModPublic()) {
@@ -98,7 +99,7 @@ private:
         }
     }
 
-    virtual void visit(AstNodeVarRef* nodep) {
+    virtual void visit(AstNodeVarRef* nodep) VL_OVERRIDE {
         // VarRef: Resolve its reference
         if (nodep->varp()) {
             nodep->varp()->usedParam(true);
@@ -106,7 +107,7 @@ private:
         iterateChildren(nodep);
     }
 
-    virtual void visit(AstNodeFTask* nodep) {
+    virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
         // NodeTask: Remember its name for later resolution
         // Remember the existing symbol table scope
         m_ftaskp = nodep;
@@ -116,14 +117,14 @@ private:
             nodep->scopeNamep(new AstScopeName(nodep->fileline()));
         }
     }
-    virtual void visit(AstNodeFTaskRef* nodep) {
+    virtual void visit(AstNodeFTaskRef* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         if (nodep->taskp() && (nodep->taskp()->dpiContext() || nodep->taskp()->dpiExport())) {
             nodep->scopeNamep(new AstScopeName(nodep->fileline()));
         }
     }
 
-    virtual void visit(AstSenItem* nodep) {
+    virtual void visit(AstSenItem* nodep) VL_OVERRIDE {
         // Remove bit selects, and bark if it's not a simple variable
         iterateChildren(nodep);
         if (nodep->isClocked()) {
@@ -167,18 +168,18 @@ private:
                 did = 0;
                 if (AstNodeSel* selp = VN_CAST(nodep->sensp(), NodeSel)) {
                     AstNode* fromp = selp->fromp()->unlinkFrBack();
-                    selp->replaceWith(fromp); selp->deleteTree(); VL_DANGLING(selp);
+                    selp->replaceWith(fromp); VL_DO_DANGLING(selp->deleteTree(), selp);
                     did = 1;
                 }
                 // NodeSel doesn't include AstSel....
                 if (AstSel* selp = VN_CAST(nodep->sensp(), Sel)) {
                     AstNode* fromp = selp->fromp()->unlinkFrBack();
-                    selp->replaceWith(fromp); selp->deleteTree(); VL_DANGLING(selp);
+                    selp->replaceWith(fromp); VL_DO_DANGLING(selp->deleteTree(), selp);
                     did = 1;
                 }
                 if (AstNodePreSel* selp = VN_CAST(nodep->sensp(), NodePreSel)) {
                     AstNode* fromp = selp->lhsp()->unlinkFrBack();
-                    selp->replaceWith(fromp); selp->deleteTree(); VL_DANGLING(selp);
+                    selp->replaceWith(fromp); VL_DO_DANGLING(selp->deleteTree(), selp);
                     did = 1;
                 }
             }
@@ -190,11 +191,11 @@ private:
             nodep->v3error("Unsupported: Complex statement in sensitivity list");
         }
     }
-    virtual void visit(AstSenGate* nodep) {
+    virtual void visit(AstSenGate* nodep) VL_OVERRIDE {
         nodep->v3fatalSrc("SenGates shouldn't be in tree yet");
     }
 
-    virtual void visit(AstNodePreSel* nodep) {
+    virtual void visit(AstNodePreSel* nodep) VL_OVERRIDE {
         if (!nodep->attrp()) {
             iterateChildren(nodep);
             // Constification may change the fromp() to a constant, which will lose the
@@ -226,7 +227,7 @@ private:
         }
     }
 
-    virtual void visit(AstCaseItem* nodep) {
+    virtual void visit(AstCaseItem* nodep) VL_OVERRIDE {
         // Move default caseItems to the bottom of the list
         // That saves us from having to search each case list twice, for non-defaults and defaults
         iterateChildren(nodep);
@@ -238,21 +239,21 @@ private:
         }
     }
 
-    virtual void visit(AstPragma* nodep) {
+    virtual void visit(AstPragma* nodep) VL_OVERRIDE {
         if (nodep->pragType() == AstPragmaType::PUBLIC_MODULE) {
             UASSERT_OBJ(m_modp, nodep, "PUBLIC_MODULE not under a module");
             m_modp->modPublic(true);
-            nodep->unlinkFrBack(); pushDeletep(nodep); VL_DANGLING(nodep);
+            nodep->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(nodep), nodep);
         }
         else if (nodep->pragType() == AstPragmaType::PUBLIC_TASK) {
             UASSERT_OBJ(m_ftaskp, nodep, "PUBLIC_TASK not under a task");
             m_ftaskp->taskPublic(true);
             m_modp->modPublic(true);  // Need to get to the task...
-            nodep->unlinkFrBack(); pushDeletep(nodep); VL_DANGLING(nodep);
+            nodep->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(nodep), nodep);
         }
         else if (nodep->pragType() == AstPragmaType::COVERAGE_BLOCK_OFF) {
             if (!v3Global.opt.coverageLine()) {  // No need for block statements; may optimize better without
-                nodep->unlinkFrBack(); pushDeletep(nodep); VL_DANGLING(nodep);
+                nodep->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(nodep), nodep);
             }
         }
         else {
@@ -270,7 +271,7 @@ private:
             if (!inPct && ch=='%') {
                 inPct = true;
                 fmt = ch;
-            } else if (inPct && (isdigit(ch) || ch=='.')) {
+            } else if (inPct && (isdigit(ch) || ch=='.' || ch=='-')) {
                 fmt += ch;
             } else if (inPct) {
                 inPct = false;
@@ -343,7 +344,7 @@ private:
                     }
                     newFormat.append(str);
                     AstNode *nextp = argp->nextp();
-                    argp->unlinkFrBack(); pushDeletep(argp); VL_DANGLING(argp);
+                    argp->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(argp), argp);
                     argp = nextp;
                 } else {
                     newFormat.append("%?");  // V3Width to figure it out
@@ -359,31 +360,31 @@ private:
         if (filep && filep->varp()) filep->varp()->attrFileDescr(true);
     }
 
-    virtual void visit(AstFOpen* nodep) {
+    virtual void visit(AstFOpen* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         expectDescriptor(nodep, VN_CAST(nodep->filep(), NodeVarRef));
     }
-    virtual void visit(AstFClose* nodep) {
+    virtual void visit(AstFClose* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         expectDescriptor(nodep, VN_CAST(nodep->filep(), NodeVarRef));
     }
-    virtual void visit(AstFEof* nodep) {
+    virtual void visit(AstFEof* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         expectDescriptor(nodep, VN_CAST(nodep->filep(), NodeVarRef));
     }
-    virtual void visit(AstFRead* nodep) {
+    virtual void visit(AstFRead* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         expectDescriptor(nodep, VN_CAST(nodep->filep(), NodeVarRef));
     }
-    virtual void visit(AstFScanF* nodep) {
+    virtual void visit(AstFScanF* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         expectFormat(nodep, nodep->text(), nodep->exprsp(), true);
     }
-    virtual void visit(AstSScanF* nodep) {
+    virtual void visit(AstSScanF* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         expectFormat(nodep, nodep->text(), nodep->exprsp(), true);
     }
-    virtual void visit(AstSFormatF* nodep) {
+    virtual void visit(AstSFormatF* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         // Cleanup old-school displays without format arguments
         if (!nodep->hasFormat()) {
@@ -392,7 +393,7 @@ private:
                 && VN_CAST(nodep->exprsp(), Const)->num().isFromString()) {
                 AstConst* fmtp = VN_CAST(nodep->exprsp()->unlinkFrBack(), Const);
                 nodep->text(fmtp->num().toString());
-                pushDeletep(fmtp); VL_DANGLING(fmtp);
+                VL_DO_DANGLING(pushDeletep(fmtp), fmtp);
             }
             nodep->hasFormat(true);
         }
@@ -405,7 +406,7 @@ private:
         }
     }
 
-    virtual void visit(AstUdpTable* nodep) {
+    virtual void visit(AstUdpTable* nodep) VL_OVERRIDE {
         UINFO(5,"UDPTABLE  "<<nodep<<endl);
         if (!v3Global.opt.bboxUnsup()) {
             // We don't warn until V3Inst, so that UDPs that are in libraries and
@@ -432,30 +433,27 @@ private:
                     }
                 }
             }
-            nodep->unlinkFrBack(); pushDeletep(nodep); VL_DANGLING(nodep);
+            nodep->unlinkFrBack(); VL_DO_DANGLING(pushDeletep(nodep), nodep);
         }
     }
 
-    virtual void visit(AstScCtor* nodep) {
+    virtual void visit(AstScCtor* nodep) VL_OVERRIDE {
         // Constructor info means the module must remain public
         m_modp->modPublic(true);
         iterateChildren(nodep);
     }
-    virtual void visit(AstScDtor* nodep) {
+    virtual void visit(AstScDtor* nodep) VL_OVERRIDE {
         // Destructor info means the module must remain public
         m_modp->modPublic(true);
         iterateChildren(nodep);
     }
-    virtual void visit(AstScInt* nodep) {
+    virtual void visit(AstScInt* nodep) VL_OVERRIDE {
         // Special class info means the module must remain public
         m_modp->modPublic(true);
         iterateChildren(nodep);
     }
 
-    virtual void visit(AstNode* nodep) {
-        // Default: Just iterate
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
@@ -484,27 +482,26 @@ private:
     VL_DEBUG_FUNC;  // Declare debug()
 
     // VISITs
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         // Iterate modules backwards, in bottom-up order.
         iterateChildrenBackwards(nodep);
     }
-    virtual void visit(AstNodeModule* nodep) {
-        m_modp = nodep;
-        iterateChildren(nodep);
-        m_modp = NULL;
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        AstNodeModule* origModp = m_modp;
+        {
+            m_modp = nodep;
+            iterateChildren(nodep);
+        }
+        m_modp = origModp;
     }
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         // Parent module inherits child's publicity
         if (nodep->modp()->modPublic()) m_modp->modPublic(true);
         //** No iteration for speed
     }
-    virtual void visit(AstNodeMath* nodep) {
-        // Speedup
-    }
-    virtual void visit(AstNode* nodep) {
-        // Default: Just iterate
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     explicit LinkBotupVisitor(AstNetlist* rootp) {
