@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -26,10 +22,19 @@
 
 #include "V3Error.h"
 
+#include <cmath>
+#include <limits>
 #include <vector>
 
 //============================================================================
 
+// Return if two numbers within Epsilon of each other
+inline bool v3EpsilonEqual(double a, double b) {
+    return fabs(a - b) <= (std::numeric_limits<double>::epsilon() * std::max(1.0, std::max(a, b)));
+}
+
+//============================================================================
+
 class AstNode;
 
 class V3Number {
@@ -151,7 +156,7 @@ public:
     V3Number(VerilogStringLiteral, AstNode* nodep, const string& str);
     class String {};
     V3Number(String, AstNode* nodep, const string& value) { init(nodep, 0); setString(value); }
-    V3Number(const V3Number* nump, int width = 1) {
+    explicit V3Number(const V3Number* nump, int width = 1) {
         init(NULL, width);
         m_fileline = nump->fileline();
     }
@@ -175,7 +180,7 @@ private:
         for (int i=0; i<words(); i++) m_value[i] = m_valueX[i] = 0;
     }
     void setNames(AstNode* nodep);
-    static string displayPad(size_t fmtsize, char pad, const string& in);
+    static string displayPad(size_t fmtsize, char pad, bool left, const string& in);
     string displayed(FileLine* fl, const string& vformat) const;
     string displayed(const string& vformat) const {
         return displayed(m_fileline, vformat);
