@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -100,6 +96,24 @@ public:
     ~V3OptionsImp() {}
 };
 
+//######################################################################
+// V3LangCode class functions
+
+V3LangCode::V3LangCode(const char* textp) {
+    // Return code for given string, or ERROR, which is a bad code
+    for (int codei = V3LangCode::L_ERROR; codei < V3LangCode::_ENUM_END; ++codei) {
+        V3LangCode code = V3LangCode(codei);
+        if (0 == VL_STRCASECMP(textp, code.ascii())) {
+            m_e = code;
+            return;
+        }
+    }
+    m_e = V3LangCode::L_ERROR;
+}
+
+//######################################################################
+// V3Options class functions
+
 void V3Options::addIncDirUser(const string& incdir) {
     m_impp->addIncDirUser(incdir);
 }
@@ -182,9 +196,7 @@ void V3Options::checkParameters() {
 }
 
 void V3Options::addCppFile(const string& filename) {
-    if (m_cppFiles.find(filename) == m_cppFiles.end()) {
-        m_cppFiles.insert(filename);
-    }
+    m_cppFiles.insert(filename);
 }
 void V3Options::addCFlags(const string& filename) {
     m_cFlags.push_back(filename);
@@ -193,9 +205,7 @@ void V3Options::addLdLibs(const string& filename) {
     m_ldLibs.push_back(filename);
 }
 void V3Options::addFuture(const string& flag) {
-    if (m_futures.find(flag) == m_futures.end()) {
-        m_futures.insert(flag);
-    }
+    m_futures.insert(flag);
 }
 bool V3Options::isFuture(const string& flag) const {
     return m_futures.find(flag) != m_futures.end();
@@ -204,25 +214,19 @@ bool V3Options::isLibraryFile(const string& filename) const {
     return m_libraryFiles.find(filename) != m_libraryFiles.end();
 }
 void V3Options::addLibraryFile(const string& filename) {
-    if (m_libraryFiles.find(filename) == m_libraryFiles.end()) {
-        m_libraryFiles.insert(filename);
-    }
+    m_libraryFiles.insert(filename);
 }
 bool V3Options::isClocker(const string& signame) const {
     return m_clockers.find(signame) != m_clockers.end();
 }
 void V3Options::addClocker(const string& signame) {
-    if (m_clockers.find(signame) == m_clockers.end()) {
-        m_clockers.insert(signame);
-    }
+    m_clockers.insert(signame);
 }
 bool V3Options::isNoClocker(const string& signame) const {
     return m_noClockers.find(signame) != m_noClockers.end();
 }
 void V3Options::addNoClocker(const string& signame) {
-    if (m_noClockers.find(signame) == m_noClockers.end()) {
-        m_noClockers.insert(signame);
-    }
+    m_noClockers.insert(signame);
 }
 void V3Options::addVFile(const string& filename) {
     // We use a list for v files, because it's legal to have includes
@@ -239,7 +243,7 @@ void V3Options::addArg(const string& arg) {
 
 string V3Options::allArgsString() {
     string out;
-    for (std::list<string>::iterator it=m_impp->m_allArgs.begin();
+    for (std::list<string>::const_iterator it = m_impp->m_allArgs.begin();
          it != m_impp->m_allArgs.end(); ++it) {
         if (out != "") out += " ";
         out += *it;
@@ -247,20 +251,6 @@ string V3Options::allArgsString() {
     return out;
 }
 
-//######################################################################
-// V3LangCode class functions
-
-V3LangCode::V3LangCode(const char* textp) {
-    // Return code for given string, or ERROR, which is a bad code
-    for (int codei=V3LangCode::L_ERROR; codei<V3LangCode::_ENUM_END; ++codei) {
-        V3LangCode code = V3LangCode(codei);
-        if (0 == VL_STRCASECMP(textp, code.ascii())) {
-            m_e = code; return;
-        }
-    }
-    m_e = V3LangCode::L_ERROR;
-}
-
 //######################################################################
 // File searching
 
@@ -374,7 +364,12 @@ string V3Options::filePath(FileLine* fl, const string& modname, const string& la
 
 void V3Options::filePathLookedMsg(FileLine* fl, const string& modname) {
     static bool shown_notfound_msg = false;
-    if (!shown_notfound_msg) {
+    if (modname.find("__Vhsh") != string::npos) {
+        std::cerr << V3Error::warnMore() << "... Unsupported: Name is longer than 127 characters;"
+                  << " automatic file lookup not supported.\n";
+        std::cerr << V3Error::warnMore() << "... Suggest putting filename with this module/package"
+                  << " onto command line instead.\n";
+    } else if (!shown_notfound_msg) {
         shown_notfound_msg = true;
         if (m_impp->m_incDirUsers.empty()) {
             fl->v3error("This may be because there's no search path specified with -I<dir>."<<endl);
@@ -661,10 +656,10 @@ bool V3Options::onoff(const char* sw, const char* arg, bool& flag) {
     else if (0==strncmp(sw, "-no-", 4) && (0==strcmp(sw+4, arg+1))) { flag = false; return true; }
     return false;
 }
-bool V3Options::onoffb(const char* sw, const char* arg, VOptionBool& bflag) {
+bool V3Options::onoffb(const char* sw, const char* arg, VOptionBool& flagr) {
     bool flag;
-    if (onoff(sw, arg, flag/*ref*/)) {
-        bflag.setTrueOrFalse(flag);
+    if (onoff(sw, arg, flag /*ref*/)) {
+        flagr.setTrueOrFalse(flag);
         return true;
     } else {
         return false;
@@ -732,9 +727,8 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             // Allow gnu -- switches
             if (sw[0]=='-' && sw[1]=='-') ++sw;
             bool hadSwitchPart1 = true;
-            if (0) {}
             // Single switches
-            else if (!strcmp(sw, "-E"))                         { m_preprocOnly = true; }
+            if (!strcmp(sw, "-E"))                              { m_preprocOnly = true; }
             else if ( onoffb(sw, "-MMD", bflag/*ref*/))         { m_makeDepend = bflag; }
             else if ( onoff (sw, "-MP", flag/*ref*/))           { m_makePhony = flag; }
             else if (!strcmp(sw, "-P"))                         { m_preprocNoLine = true; }
@@ -783,6 +777,7 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             else if ( onoff (sw, "-public", flag/*ref*/))            { m_public = flag; }
             else if ( onoff (sw, "-public-flat-rw", flag/*ref*/) )   { m_publicFlatRW = flag; v3Global.dpi(true); }
             else if (!strncmp(sw, "-pvalue+", strlen("-pvalue+")))   { addParameter(string(sw+strlen("-pvalue+")), false); }
+            else if ( onoff (sw, "-quiet-exit", flag/*ref*/))        { m_quietExit = flag; }
             else if ( onoff (sw, "-relative-cfuncs", flag/*ref*/))   { m_relativeCFuncs = flag; }
             else if ( onoff (sw, "-relative-includes", flag/*ref*/)) { m_relativeIncludes = flag; }
             else if ( onoff (sw, "-report-unoptflat", flag/*ref*/))  { m_reportUnoptflat = flag; }
@@ -791,6 +786,7 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
             else if ( onoffb(sw, "-skip-identical", bflag/*ref*/))   { m_skipIdentical = bflag; }
             else if ( onoff (sw, "-stats", flag/*ref*/))             { m_stats = flag; }
             else if ( onoff (sw, "-stats-vars", flag/*ref*/))        { m_statsVars = flag; m_stats |= flag; }
+            else if ( onoff (sw, "-structs-unpacked", flag/*ref*/))  { m_structsPacked = flag; }
             else if (!strcmp(sw, "-sv"))                             { m_defaultLanguage = V3LangCode::L1800_2005; }
             else if ( onoff (sw, "-threads-coarsen", flag/*ref*/))   { m_threadsCoarsen = flag; }  // Undocumented, debug
             else if ( onoff (sw, "-trace", flag/*ref*/))             { m_trace = flag; }
@@ -943,6 +939,10 @@ void V3Options::parseOptsList(FileLine* fl, const string& optdir, int argc, char
                     fl->v3fatal("Unknown --make system specified: '"<<argv[i]<<"'");
                 }
             }
+            else if (!strcmp(sw, "-max-num-width")) {
+                shift;
+                m_maxNumWidth = atoi(argv[i]);
+            }
             else if (!strcmp(sw, "-no-l2name")) {  // Historical and undocumented
                 m_l2Name = "";
             }
@@ -1484,12 +1484,14 @@ V3Options::V3Options() {
     m_preprocNoLine = false;
     m_public = false;
     m_publicFlatRW = false;
+    m_quietExit = false;
     m_relativeCFuncs = true;
     m_relativeIncludes = false;
     m_reportUnoptflat = false;
     m_savable = false;
     m_stats = false;
     m_statsVars = false;
+    m_structsPacked = true;
     m_systemC = false;
     m_threads = 0;
     m_threadsDpiPure = true;
@@ -1513,6 +1515,7 @@ V3Options::V3Options() {
     m_gateStmts = 100;
     m_ifDepth = 0;
     m_inlineMult = 2000;
+    m_maxNumWidth = 65536;
     m_moduleRecursion = 100;
     m_outputSplit = 0;
     m_outputSplitCFuncs = 0;
@@ -1548,7 +1551,7 @@ V3Options::V3Options() {
 }
 
 V3Options::~V3Options() {
-    delete m_impp; m_impp = NULL;
+    VL_DO_CLEAR(delete m_impp, m_impp = NULL);
 }
 
 void V3Options::setDebugMode(int level) {
