@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 //  OrderGraph Class Hierarchy:
@@ -103,10 +99,16 @@ struct OrderVEdgeType {
     inline OrderVEdgeType(en _e) : m_e(_e) {}
     explicit inline OrderVEdgeType(int _e) : m_e(static_cast<en>(_e)) {}
     operator en() const { return m_e; }
-  };
-  inline bool operator==(OrderVEdgeType lhs, OrderVEdgeType rhs) { return (lhs.m_e == rhs.m_e); }
-  inline bool operator==(OrderVEdgeType lhs, OrderVEdgeType::en rhs) { return (lhs.m_e == rhs); }
-  inline bool operator==(OrderVEdgeType::en lhs, OrderVEdgeType rhs) { return (lhs == rhs.m_e); }
+};
+inline bool operator==(const OrderVEdgeType& lhs, const OrderVEdgeType& rhs) {
+    return lhs.m_e == rhs.m_e;
+}
+inline bool operator==(const OrderVEdgeType& lhs, OrderVEdgeType::en rhs) {
+    return lhs.m_e == rhs;
+}
+inline bool operator==(OrderVEdgeType::en lhs, const OrderVEdgeType& rhs) {
+    return lhs == rhs.m_e;
+}
 
 //######################################################################
 // Graph types
