@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -47,7 +43,7 @@
 #include <sys/types.h>
 
 #if defined(_WIN32) || defined(__MINGW32__)
-# include <winnt.h>   // LONG for bcrypt.h on MINGW
+# include <windows.h>   // LONG for bcrypt.h on MINGW
 # include <bcrypt.h>  // BCryptGenRandom
 # include <chrono>
 # include <direct.h>  // mkdir
@@ -268,7 +264,7 @@ string V3Os::trueRandom(size_t size) {
     // This read uses the size of the buffer.
     // Flawfinder: ignore
     if (!is.read(data, size)) {
-        v3fatal("Could not open /dev/urandom, no source of randomness. Try specifing a key instead.");
+        v3fatal("Could not open /dev/urandom, no source of randomness. Try specifying a key instead.");
     }
 #endif
     return result;
