@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2000-2020 by Wilson Snyder.  This program is free software;
-// you can redistribute it and/or modify it under the terms of either the
-// GNU Lesser General Public License Version 3 or the Perl Artistic License
+// Copyright 2000-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
+// Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// This program is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -135,7 +131,7 @@ public:
                "ps_DEFFORM", "ps_DEFVALUE", "ps_DEFPAREN", "ps_DEFARG",
                "ps_INCNAME", "ps_ERRORNAME", "ps_JOIN", "ps_STRIFY"};
         return states[s];
-    };
+    }
 
     std::stack<ProcState> m_states;  ///< Current state of parser
     int         m_off;          ///< If non-zero, ifdef level is turned off, don't dump text
@@ -285,7 +281,7 @@ public:
         m_lexp->debug(debug()>=5 ? debug() : 0);  // See also V3PreProc::debug() method
     }
     ~V3PreProcImp() {
-        if (m_lexp) { delete m_lexp; m_lexp = NULL; }
+        if (m_lexp) VL_DO_CLEAR(delete m_lexp, m_lexp = NULL);
     }
 };
 
@@ -339,7 +335,8 @@ void V3PreProcImp::define(FileLine* fl, const string& name, const string& value,
                           const string& params, bool cmdline) {
     UINFO(4,"DEFINE '"<<name<<"' as '"<<value<<"' params '"<<params<<"'"<<endl);
     if (!V3LanguageWords::isKeyword(string("`") + name).empty()) {
-        fl->v3error("Attempting to define built-in directive: '`"<<name<<"' (IEEE 2017 22.5.1)");
+        fl->v3error("Attempting to define built-in directive: '`"
+                    << name << "' (IEEE 1800-2017 22.5.1)");
     } else {
         if (defExists(name)) {
             if (!(defValue(name) == value
@@ -864,7 +861,7 @@ void V3PreProcImp::candidateDefines(VSpellCheck* spellerp) {
 
 int V3PreProcImp::getRawToken() {
     // Get a token from the file, whatever it may be.
-    while (1) {
+    while (true) {
       next_tok:
         if (m_lineAdd) {
             m_lineAdd--;
@@ -945,7 +942,7 @@ void V3PreProcImp::debugToken(int tok, const char* cmtp) {
 
 int V3PreProcImp::getStateToken() {
     // Return the next state-determined token
-    while (1) {
+    while (true) {
       next_tok:
         if (isEof()) return VP_EOF;
         int tok = getRawToken();
@@ -1175,7 +1172,7 @@ int V3PreProcImp::getStateToken() {
                     out = defineSubst(refp);
                     //NOP: out = m_preprocp->defSubstitute(out);
                 }
-                m_defRefs.pop(); VL_DANGLING(refp);
+                VL_DO_DANGLING(m_defRefs.pop(), refp);
                 if (m_defRefs.empty()) {
                     statePop();
                     if (state() == ps_JOIN) {  // Handle {left}```FOO(ARG) where `FOO(ARG) might be empty
