@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Todd Strader.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -68,7 +64,7 @@ class ProtectVisitor : public AstNVisitor {
     bool m_foundTop;                    // Have seen the top module
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         m_vfilep = new AstVFile(nodep->fileline(),
                                 v3Global.opt.makeDir()+"/"+m_libName+".sv");
         nodep->addFilesp(m_vfilep);
@@ -78,7 +74,7 @@ class ProtectVisitor : public AstNVisitor {
         iterateChildren(nodep);
     }
 
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         if (!nodep->isTop()) {
             return;
         } else {
@@ -92,7 +88,7 @@ class ProtectVisitor : public AstNVisitor {
 
         V3Hash hash = V3Hashed::uncachedHash(m_cfilep);
         m_hashValuep->addText(fl, cvtToStr(hash.fullValue())+";\n");
-        m_cHashValuep->addText(fl, cvtToStr(hash.fullValue())+";\n");
+        m_cHashValuep->addText(fl, cvtToStr(hash.fullValue())+"U;\n");
         m_foundTop = true;
     }
 
@@ -347,13 +343,14 @@ class ProtectVisitor : public AstNVisitor {
         m_cfilep->tblockp(txtp);
     }
 
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         if (!nodep->isIO()) return;
         if (VN_IS(nodep->dtypep(), UnpackArrayDType)) {
             nodep->v3error("Unsupported: unpacked arrays with protect-lib on "<<nodep->prettyNameQ());
         }
         if (nodep->direction() == VDirection::INPUT) {
-            if (nodep->isUsedClock()) {
+            if (nodep->isUsedClock()
+                || nodep->attrClocker() == VVarAttrClocker::CLOCKER_YES) {
                 handleClock(nodep);
             } else {
                 handleDataInput(nodep);
@@ -366,7 +363,7 @@ class ProtectVisitor : public AstNVisitor {
         }
     }
 
-    virtual void visit(AstNode* nodep) { }
+    virtual void visit(AstNode*) VL_OVERRIDE {}
 
     string cInputConnection(AstVar* varp) {
         string frstmt;
