@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Reloop's Transformations:
@@ -120,11 +116,11 @@ private:
                 // Replace constant index with new loop index
                 AstNode* lbitp = m_mgSelLp->bitp();
                 lbitp->replaceWith(new AstVarRef(fl, itp, false));
-                lbitp->deleteTree(); VL_DANGLING(lbitp);
+                VL_DO_DANGLING(lbitp->deleteTree(), lbitp);
                 if (m_mgSelRp) {  // else constant and no replace
                     AstNode* rbitp = m_mgSelRp->bitp();
                     rbitp->replaceWith(new AstVarRef(fl, itp, false));
-                    rbitp->deleteTree(); VL_DANGLING(lbitp);
+                    VL_DO_DANGLING(rbitp->deleteTree(), lbitp);
                 }
                 if (debug()>=9) initp->dumpTree(cout, "-new: ");
                 if (debug()>=9) whilep->dumpTree(cout, "-new: ");
@@ -133,7 +129,7 @@ private:
                 for (AssVec::iterator it=m_mgAssignps.begin(); it!=m_mgAssignps.end(); ++it) {
                     AstNodeAssign* assp = *it;
                     if (assp != bodyp) {
-                        assp->unlinkFrBack()->deleteTree(); VL_DANGLING(assp);
+                        VL_DO_DANGLING(assp->unlinkFrBack()->deleteTree(), assp);
                     }
                 }
             }
@@ -148,12 +144,12 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         m_cfuncp = nodep;
         iterateChildren(nodep);
         m_cfuncp = NULL;
     }
-    virtual void visit(AstNodeAssign* nodep) {
+    virtual void visit(AstNodeAssign* nodep) VL_OVERRIDE {
         if (!m_cfuncp) return;
 
         // Left select WordSel or ArraySel
@@ -226,12 +222,9 @@ private:
         UINFO(9, "Start merge i="<<index<<" "<<nodep<<endl);
     }
     //--------------------
-    // Default: Just iterate
-    virtual void visit(AstVar* nodep) {}  // Speedup
-    virtual void visit(AstNodeMath* nodep) {}  // Speedup
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstVar*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNodeMath*) VL_OVERRIDE {}  // Accelerate
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
