@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Split implements two separate transformations:
@@ -346,19 +342,19 @@ protected:
     virtual void makeRvalueEdges(SplitVarStdVertex* vstdp) = 0;
 
     // VISITORS
-    virtual void visit(AstAlways* nodep) = 0;
-    virtual void visit(AstNodeIf* nodep) = 0;
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE = 0;
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE = 0;
 
     // We don't do AstNodeFor/AstWhile loops, due to the standard question
     // of what is before vs. after
 
-    virtual void visit(AstAssignDly* nodep) {
+    virtual void visit(AstAssignDly* nodep) VL_OVERRIDE {
         m_inDly = true;
         UINFO(4,"    ASSIGNDLY "<<nodep<<endl);
         iterateChildren(nodep);
         m_inDly = false;
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (!m_stmtStackps.empty()) {
             AstVarScope* vscp = nodep->varScopep();
             UASSERT_OBJ(vscp, nodep, "Not linked");
@@ -422,7 +418,7 @@ protected:
         }
     }
 
-    virtual void visit(AstJumpGo* nodep) {
+    virtual void visit(AstJumpGo* nodep) VL_OVERRIDE {
         // Jumps will disable reordering at all levels
         // This is overly pessimistic; we could treat jumps as barriers, and
         // reorder everything between jumps/labels, however jumps are rare
@@ -434,7 +430,7 @@ protected:
 
     //--------------------
     // Default
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         // **** SPECIAL default type that sets PLI_ORDERING
         if (!m_stmtStackps.empty() && !nodep->isPure()) {
             UINFO(9,"         NotSplittable "<<nodep<<endl);
@@ -457,7 +453,7 @@ public:
 
     // METHODS
 protected:
-    void makeRvalueEdges(SplitVarStdVertex* vstdp) {
+    virtual void makeRvalueEdges(SplitVarStdVertex* vstdp) VL_OVERRIDE {
         for (VStack::iterator it = m_stmtStackps.begin(); it != m_stmtStackps.end(); ++it) {
             new SplitRVEdge(&m_graph, *it, vstdp);
         }
@@ -606,7 +602,7 @@ protected:
         firstp->user3p(oldBlockUser3);
     }
 
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         UINFO(4,"   ALW   "<<nodep<<endl);
         if (debug()>=9) nodep->dumpTree(cout, "   alwIn:: ");
         scoreboardClear();
@@ -614,7 +610,7 @@ protected:
         if (debug()>=9) nodep->dumpTree(cout, "   alwOut: ");
     }
 
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         UINFO(4,"     IF "<<nodep<<endl);
         iterateAndNextNull(nodep->condp());
         processBlock(nodep->ifsp());
@@ -672,13 +668,13 @@ private:
     }
 
 protected:
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         m_ifStack.push_back(nodep);
         trackNode(nodep);
         iterateChildren(nodep);
         m_ifStack.pop_back();
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         trackNode(nodep);
         iterateChildren(nodep);
     }
@@ -746,7 +742,7 @@ protected:
         return new AstSplitPlaceholder(m_origAlwaysp->fileline());
     }
 
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         // Anything that's not an if/else we assume is a leaf
         // (that is, something we won't split.) Don't visit further
         // into the leaf.
@@ -768,7 +764,7 @@ protected:
         m_addAfter[color] = clonedp;
     }
 
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         const ColorSet& colors = m_ifColorp->colors(nodep);
         typedef vl_unordered_map<uint32_t, AstNodeIf*> CloneMap;
         CloneMap clones;
@@ -825,16 +821,15 @@ public:
              it != m_removeSet.end(); ++it) {
             AstNode* np = *it;
             np->unlinkFrBack();  // Without next
-            np->deleteTree(); VL_DANGLING(np);
+            VL_DO_DANGLING(np->deleteTree(), np);
         }
     }
     virtual ~RemovePlaceholdersVisitor() {}
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
-    virtual void visit(AstSplitPlaceholder* nodep) {
+    virtual void visit(AstSplitPlaceholder* nodep) VL_OVERRIDE {
         m_removeSet.insert(nodep);
     }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 private:
     VL_UNCOPYABLE(RemovePlaceholdersVisitor);
 };
@@ -868,7 +863,7 @@ public:
                 RemovePlaceholdersVisitor removePlaceholders(*addme);
             }
             origp->unlinkFrBack();  // Without next
-            origp->deleteTree(); VL_DANGLING(origp);
+            VL_DO_DANGLING(origp->deleteTree(), origp);
         }
     }
 
@@ -876,7 +871,7 @@ public:
 
     // METHODS
 protected:
-    void makeRvalueEdges(SplitVarStdVertex* vstdp) {
+    virtual void makeRvalueEdges(SplitVarStdVertex* vstdp) VL_OVERRIDE {
         // Each 'if' depends on rvalues in its own conditional ONLY,
         // not rvalues in the if/else bodies.
         for (VStack::const_iterator it = m_stmtStackps.begin(); it != m_stmtStackps.end(); ++it) {
@@ -955,7 +950,7 @@ protected:
         if (debug()>=9) m_graph.dumpDotFilePrefixed("splitg_colored", false);
     }
 
-    virtual void visit(AstAlways* nodep) {
+    virtual void visit(AstAlways* nodep) VL_OVERRIDE {
         // build the scoreboard
         scoreboardClear();
         scanBlock(nodep->bodysp());
@@ -988,7 +983,7 @@ protected:
             emitSplit.go();
         }
     }
-    virtual void visit(AstNodeIf* nodep) {
+    virtual void visit(AstNodeIf* nodep) VL_OVERRIDE {
         UINFO(4,"     IF "<<nodep<<endl);
         m_curIfConditional = nodep;
         iterateAndNextNull(nodep->condp());
