@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -74,6 +70,14 @@ bool VString::wildmatch(const char* s, const char* p) {
     return (*s == '\0');
 }
 
+bool VString::wildmatch(const string& s, const string& p) {
+    return wildmatch(s.c_str(), p.c_str());
+}
+
+bool VString::isWildcard(const string &p) {
+    return ((p.find('*') != string::npos) || (p.find('?') != string::npos));
+}
+
 string VString::dot(const string& a, const string& dot, const string& b) {
     if (b=="") return a;
     if (a=="") return b;
@@ -114,6 +118,13 @@ string VString::spaceUnprintable(const string& str) {
     return out;
 }
 
+bool VString::isWhitespace(const string& str) {
+    for (string::const_iterator pos = str.begin(); pos != str.end(); ++pos) {
+        if (!isspace(*pos)) return false;
+    }
+    return true;
+}
+
 //######################################################################
 // VHashSha256
 
@@ -133,8 +144,8 @@ static inline uint32_t shaRotr32(uint32_t lhs, uint32_t rhs) {
     return lhs >> rhs | lhs << (32 - rhs);
 }
 
-static inline void sha256Block(uint32_t* h, uint32_t* chunk) VL_ATTR_ALWINLINE;
-static inline void sha256Block(uint32_t* h, uint32_t* chunk) {
+static inline void sha256Block(uint32_t* h, const uint32_t* chunk) VL_ATTR_ALWINLINE;
+static inline void sha256Block(uint32_t* h, const uint32_t* chunk) {
     uint32_t ah[8];
     const uint32_t* p = chunk;
 
@@ -405,7 +416,7 @@ VSpellCheck::EditDistance VSpellCheck::cutoffDistance(size_t goal_len, size_t ca
     size_t max_length = std::max(goal_len, candidate_len);
     size_t min_length = std::min(goal_len, candidate_len);
     if (max_length <= 1) return 0;
-    if (max_length - min_length <= 1) return std::max(max_length / 3, (size_t)1);
+    if (max_length - min_length <= 1) return std::max(max_length / 3, static_cast<size_t>(1));
     return (max_length + 2) / 3;
 }
 
