@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -63,6 +59,10 @@ public:
     // METHODS (generic string utilities)
     // Return true if p with ? or *'s matches s
     static bool wildmatch(const char* s, const char* p);
+    // Return true if p with ? or *'s matches s
+    static bool wildmatch(const string& s, const string& p);
+    // Return true if this is a wildcard string (contains * or ?)
+    static bool isWildcard(const string &p);
     // Return {a}{dot}{b}, omitting dot if a or b are empty
     static string dot(const string& a, const string& dot, const string& b);
     // Convert string to lowercase (tolower)
@@ -74,6 +74,8 @@ public:
     // Replace any unprintable with space
     // This includes removing tabs, so column tracking is correct
     static string spaceUnprintable(const string& str);
+    // Return true if only whitespace or ""
+    static bool isWhitespace(const string& str);
 };
 
 //######################################################################
