@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Trace's Transformations:
@@ -449,9 +445,7 @@ private:
                         break;
                     } else {
                         uint32_t acode = cfvertexp->activityCode();
-                        if (actset.find(acode) == actset.end()) {
-                            actset.insert(acode);
-                        }
+                        actset.insert(acode);
                     }
                 }
                 // If a trace doesn't have activity, it's constant, and we
@@ -587,7 +581,7 @@ private:
             m_fullSubStmts += EmitCBaseCounterVisitor(nodep).count();
         } else {
             // Duplicates don't need a TraceInc
-            pushDeletep(nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(pushDeletep(nodep), nodep);
         }
         return incAddp;
     }
@@ -613,7 +607,7 @@ private:
     }
 
     // VISITORS
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         m_code = 1;  // Multiple TopScopes will require fixing how code#s
         // are assigned as duplicate varscopes must result in the same tracing code#.
 
@@ -641,17 +635,17 @@ private:
         assignActivity();
         putTracesIntoTree();
     }
-    virtual void visit(AstNodeModule* nodep) {
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
         if (nodep->isTop()) m_topModp = nodep;
         iterateChildren(nodep);
     }
-    virtual void visit(AstTopScope* nodep) {
+    virtual void visit(AstTopScope* nodep) VL_OVERRIDE {
         AstScope* scopep = nodep->scopep();
         UASSERT_OBJ(scopep, nodep, "No scope found on top level");
         m_highScopep = scopep;
         iterateChildren(nodep);
     }
-    virtual void visit(AstCCall* nodep) {
+    virtual void visit(AstCCall* nodep) VL_OVERRIDE {
         UINFO(8,"   CCALL "<<nodep<<endl);
         if (!m_finding && !nodep->user2()) {
             // See if there are other calls in same statement list;
@@ -669,7 +663,7 @@ private:
         }
         iterateChildren(nodep);
     }
-    virtual void visit(AstCFunc* nodep) {
+    virtual void visit(AstCFunc* nodep) VL_OVERRIDE {
         UINFO(8,"   CFUNC "<<nodep<<endl);
         if (nodep->funcType() == AstCFuncType::TRACE_INIT) {
             m_initFuncp = nodep;
@@ -693,7 +687,7 @@ private:
         iterateChildren(nodep);
         m_funcp = NULL;
     }
-    virtual void visit(AstTraceInc* nodep) {
+    virtual void visit(AstTraceInc* nodep) VL_OVERRIDE {
         UINFO(8,"   TRACE "<<nodep<<endl);
         UASSERT_OBJ(!m_finding, nodep, "Traces should have been removed in prev step.");
         nodep->unlinkFrBack();
@@ -706,7 +700,7 @@ private:
         iterateChildren(nodep);
         m_tracep = NULL;
     }
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (m_tracep) {
             UASSERT_OBJ(nodep->varScopep(), nodep, "No var scope?");
             UASSERT_OBJ(!nodep->lvalue(), nodep, "Lvalue in trace?  Should be const.");
@@ -732,9 +726,7 @@ private:
         }
     }
     //--------------------
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
 
 public:
     // CONSTRUCTORS
