@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 // V3Tristate's Transformations:
@@ -136,6 +132,7 @@ public:
     // CONSTRUCTORS
     TristateGraph() { clear(); }
     virtual ~TristateGraph() { clear(); }
+    VL_UNCOPYABLE(TristateGraph);
 
 private:
     // METHODS
@@ -212,6 +209,7 @@ private:
 
 public:
     // METHODS
+    bool empty() const { return m_graph.empty(); }
     void clear() {
         for (V3GraphVertex* itp = m_graph.verticesBeginp(); itp; itp=itp->verticesNextp()) {
             TristateVertex* vvertexp = static_cast<TristateVertex*>(itp);
@@ -286,7 +284,7 @@ class TristatePinVisitor : public TristateBaseVisitor {
     TristateGraph& m_tgraph;
     bool m_lvalue;  // Flip to be an LVALUE
     // VISITORS
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         if (m_lvalue && !nodep->lvalue()) {
             UINFO(9,"  Flip-to-LValue "<<nodep<<endl);
             nodep->lvalue(true);
@@ -298,19 +296,18 @@ class TristatePinVisitor : public TristateBaseVisitor {
             m_tgraph.setTristate(nodep->varp());
         }
     }
-    virtual void visit(AstArraySel* nodep) {
+    virtual void visit(AstArraySel* nodep) VL_OVERRIDE {
         // Doesn't work because we'd set lvalue on the array index's var
         UASSERT_OBJ(!m_lvalue, nodep, "ArraySel conversion to output, under tristate node");
         iterateChildren(nodep);
     }
-    virtual void visit(AstSliceSel* nodep) {
+    virtual void visit(AstSliceSel* nodep) VL_OVERRIDE {
         // Doesn't work because we'd set lvalue on the array index's var
         UASSERT_OBJ(!m_lvalue, nodep, "SliceSel conversion to output, under tristate node");
         iterateChildren(nodep);
     }
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     TristatePinVisitor(AstNode* nodep, TristateGraph& tgraph, bool lvalue)
@@ -429,9 +426,9 @@ class TristateVisitor : public TristateBaseVisitor {
         VarMap::iterator it = m_lhsmap.find(key);
         UINFO(9,"    mapInsertLhsVarRef "<<nodep<<endl);
         if (it == m_lhsmap.end()) {  // Not found
-            RefVec* refs = new RefVec();
-            refs->push_back(nodep);
-            m_lhsmap.insert(make_pair(key, refs));
+            RefVec* refsp = new RefVec();
+            refsp->push_back(nodep);
+            m_lhsmap.insert(make_pair(key, refsp));
         } else {
             it->second->push_back(nodep);
         }
@@ -512,14 +509,14 @@ class TristateVisitor : public TristateBaseVisitor {
         for (VarMap::iterator nextit, it = m_lhsmap.begin(); it != m_lhsmap.end(); it = nextit) {
             nextit = it; ++nextit;
             AstVar* invarp = it->first;
-            RefVec* refs = it->second;
+            RefVec* refsp = it->second;
 
             // Figure out if this var needs tristate expanded.
             if (!m_tgraph.isTristate(invarp)) {
                 // This var has no tristate logic, so we leave it alone.
                 UINFO(8, "  NO TRISTATE ON:" << invarp << endl);
                 m_lhsmap.erase(invarp);
-                delete refs;
+                VL_DO_DANGLING(delete refsp, refsp);
                 continue;
             }
 
@@ -559,7 +556,7 @@ class TristateVisitor : public TristateBaseVisitor {
             AstNode* undrivenp = NULL;
 
             // loop through the lhs drivers to build the driver resolution logic
-            for (RefVec::iterator ii=refs->begin(); ii != refs->end(); ++ii) {
+            for (RefVec::iterator ii = refsp->begin(); ii != refsp->end(); ++ii) {
                 AstVarRef* refp = (*ii);
                 int w = lhsp->width();
 
@@ -623,7 +620,7 @@ class TristateVisitor : public TristateBaseVisitor {
                                        new AstConst(invarp->fileline(), pull));
                 orp = new AstOr(invarp->fileline(), orp, undrivenp);
             } else {
-                undrivenp->deleteTree(); VL_DANGLING(undrivenp);
+                VL_DO_DANGLING(undrivenp->deleteTree(), undrivenp);
             }
             if (envarp) {
                 nodep->addStmtp(new AstAssignW(enp->fileline(),
@@ -641,12 +638,12 @@ class TristateVisitor : public TristateBaseVisitor {
             nodep->addStmtp(assp);
             // Delete the map and vector list now that we have expanded it.
             m_lhsmap.erase(invarp);
-            delete refs;
+            VL_DO_DANGLING(delete refsp, refsp);
         }
     }
 
     // VISITORS
-    virtual void visit(AstConst* nodep) {
+    virtual void visit(AstConst* nodep) VL_OVERRIDE {
         UINFO(9,dbgState()<<nodep<<endl);
         if (m_graphing) {
             if (!m_alhs && nodep->num().hasZ()) {
@@ -662,7 +659,7 @@ class TristateVisitor : public TristateBaseVisitor {
                 AstNode* newp = new AstVarRef(nodep->fileline(), varp, true);
                 UINFO(9," const->"<<newp<<endl);
                 nodep->replaceWith(newp);
-                pushDeletep(nodep); VL_DANGLING(nodep);
+                VL_DO_DANGLING(pushDeletep(nodep), nodep);
             }
             else if (m_tgraph.isTristate(nodep)) {
                 m_tgraph.didProcess(nodep);
@@ -676,13 +673,13 @@ class TristateVisitor : public TristateBaseVisitor {
                 AstConst* newconstp = new AstConst(fl, num1);
                 AstConst* enp       = new AstConst(fl, numz0);
                 nodep->replaceWith(newconstp);
-                pushDeletep(nodep); VL_DANGLING(nodep);
+                VL_DO_DANGLING(pushDeletep(nodep), nodep);
                 newconstp->user1p(enp);  // Propagate up constant with non-Z bits as 1
             }
         }
     }
 
-    virtual void visit(AstCond* nodep) {
+    virtual void visit(AstCond* nodep) VL_OVERRIDE {
         if (m_graphing) {
             iterateChildren(nodep);
             if (m_alhs) {
@@ -725,7 +722,7 @@ class TristateVisitor : public TristateBaseVisitor {
         }
     }
 
-    virtual void visit(AstSel* nodep) {
+    virtual void visit(AstSel* nodep) VL_OVERRIDE {
         if (m_graphing) {
             iterateChildren(nodep);
             if (m_alhs) {
@@ -763,7 +760,7 @@ class TristateVisitor : public TristateBaseVisitor {
         }
     }
 
-    virtual void visit(AstConcat* nodep) {
+    virtual void visit(AstConcat* nodep) VL_OVERRIDE {
         if (m_graphing) {
             iterateChildren(nodep);
             if (m_alhs) {
@@ -813,7 +810,7 @@ class TristateVisitor : public TristateBaseVisitor {
         }
     }
 
-    virtual void visit(AstBufIf1* nodep) {
+    virtual void visit(AstBufIf1* nodep) VL_OVERRIDE {
         // For BufIf1, the enable is the LHS expression
         iterateChildren(nodep);
         UINFO(9,dbgState()<<nodep<<endl);
@@ -841,7 +838,7 @@ class TristateVisitor : public TristateBaseVisitor {
             nodep->replaceWith(expr2p);
             UINFO(9,"   bufif  datap="<<expr2p<<endl);
             UINFO(9,"   bufif  enp="<<enp<<endl);
-            pushDeletep(nodep); VL_DANGLING(nodep);
+            VL_DO_DANGLING(pushDeletep(nodep), nodep);
         }
     }
 
@@ -899,10 +896,10 @@ class TristateVisitor : public TristateBaseVisitor {
             expr2p->user1p(NULL);
         }
     }
-    virtual void visit(AstAnd* nodep) {
+    virtual void visit(AstAnd* nodep) VL_OVERRIDE {
         visitAndOr(nodep, true);
     }
-    virtual void visit(AstOr* nodep) {
+    virtual void visit(AstOr* nodep) VL_OVERRIDE {
         visitAndOr(nodep, false);
     }
 
@@ -939,10 +936,10 @@ class TristateVisitor : public TristateBaseVisitor {
             m_alhs = false;
         }
     }
-    virtual void visit(AstAssignW* nodep) {
+    virtual void visit(AstAssignW* nodep) VL_OVERRIDE {
         visitAssign(nodep);
     }
-    virtual void visit(AstAssign* nodep) {
+    virtual void visit(AstAssign* nodep) VL_OVERRIDE {
         visitAssign(nodep);
     }
 
@@ -976,7 +973,7 @@ class TristateVisitor : public TristateBaseVisitor {
                 if (debug()>=9) nodep->dumpTree(cout, "-caseeq-old: ");
                 if (debug()>=9) newp->dumpTree(cout, "-caseeq-new: ");
                 nodep->replaceWith(newp);
-                pushDeletep(nodep); VL_DANGLING(nodep);
+                VL_DO_DANGLING(pushDeletep(nodep), nodep);
             } else {
                 checkUnhandled(nodep);
             }
@@ -993,20 +990,20 @@ class TristateVisitor : public TristateBaseVisitor {
             return;
         }
     }
-    virtual void visit(AstEqCase* nodep) {
+    virtual void visit(AstEqCase* nodep) VL_OVERRIDE {
         visitCaseEq(nodep, false);
     }
-    virtual void visit(AstNeqCase* nodep) {
+    virtual void visit(AstNeqCase* nodep) VL_OVERRIDE {
         visitCaseEq(nodep, true);
     }
-    virtual void visit(AstEqWild* nodep) {
+    virtual void visit(AstEqWild* nodep) VL_OVERRIDE {
         visitEqNeqWild(nodep);
     }
-    virtual void visit(AstNeqWild* nodep) {
+    virtual void visit(AstNeqWild* nodep) VL_OVERRIDE {
         visitEqNeqWild(nodep);
     }
 
-    virtual void visit(AstPull* nodep) {
+    virtual void visit(AstPull* nodep) VL_OVERRIDE {
         UINFO(9,dbgState()<<nodep<<endl);
         AstVarRef* varrefp = NULL;
         if (VN_IS(nodep->lhsp(), VarRef)) {
@@ -1040,7 +1037,7 @@ class TristateVisitor : public TristateBaseVisitor {
         }
         if (!m_graphing) {
             nodep->unlinkFrBack();
-            pushDeletep(nodep); VL_DANGLING(nodep);  // Node must persist as user3p points to it
+            VL_DO_DANGLING(pushDeletep(nodep), nodep);  // Node must persist as user3p points to it
         }
     }
 
@@ -1083,7 +1080,7 @@ class TristateVisitor : public TristateBaseVisitor {
     //                     __out(to-resolver-only)
     //     const inout  Spec says illegal
     //     const output Unsupported; Illegal?
-    virtual void visit(AstPin* nodep) {
+    virtual void visit(AstPin* nodep) VL_OVERRIDE {
         if (m_graphing) {
             if (nodep->user2() & U2_GRAPHING) return;  // This pin is already expanded
             nodep->user2(U2_GRAPHING);
@@ -1155,7 +1152,9 @@ class TristateVisitor : public TristateBaseVisitor {
             AstVar* outModVarp = static_cast<AstVar*>(nodep->modVarp()->user4p());
             if (!outModVarp) {
                 // At top, no need for __out as might be input only. Otherwise resolvable.
-                UASSERT_OBJ(m_modp->isTop(), nodep, "Unlinked");
+                if (!m_modp->isTop()) {
+                    nodep->v3error("Unsupported: tristate in top-level IO: " << nodep->prettyNameQ());
+                }
             } else {
                 AstNode* outexprp = nodep->exprp()->cloneTree(false);  // Note has lvalue() set
                 outpinp = new AstPin(nodep->fileline(),
@@ -1236,7 +1235,7 @@ class TristateVisitor : public TristateBaseVisitor {
         }
     }
 
-    virtual void visit(AstVarRef* nodep) {
+    virtual void visit(AstVarRef* nodep) VL_OVERRIDE {
         UINFO(9,dbgState()<<nodep<<endl);
         if (m_graphing) {
             if (nodep->lvalue()) {
@@ -1270,7 +1269,7 @@ class TristateVisitor : public TristateBaseVisitor {
         }
     }
 
-    virtual void visit(AstVar* nodep) {
+    virtual void visit(AstVar* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         UINFO(9,dbgState()<<nodep<<endl);
         if (m_graphing) {
@@ -1303,53 +1302,64 @@ class TristateVisitor : public TristateBaseVisitor {
         }
     }
 
-    virtual void visit(AstNodeModule* nodep) {
-        UINFO(8, nodep<<endl);
-        UASSERT_OBJ(!m_graphing, nodep,
-                    "Modules under modules not supported");  // Lots of per-module state breaks
-        // Clear state
-        m_tgraph.clear();
-        m_unique = 0;
-        m_logicp = NULL;
-        m_lhsmap.clear();
-        m_modp = nodep;
-        // Walk the graph, finding all variables and tristate constructs
+    virtual void visit(AstNodeModule* nodep) VL_OVERRIDE {
+        UINFO(8, nodep << endl);
+        AstNodeModule* origModp = m_modp;
+        bool origGraphing = m_graphing;
+        int origUnique = m_unique;
+        VarMap origLhsmap = m_lhsmap;
+        // Not preserved, needs pointer instead: TristateGraph origTgraph = m_tgraph;
+        UASSERT_OBJ(m_tgraph.empty(), nodep, "Unsupported: NodeModule under NodeModule");
         {
-            m_graphing = true;
-            iterateChildren(nodep);
+            // Clear state
             m_graphing = false;
+            m_tgraph.clear();
+            m_unique = 0;
+            m_logicp = NULL;
+            m_lhsmap.clear();
+            m_modp = nodep;
+            // Walk the graph, finding all variables and tristate constructs
+            {
+                m_graphing = true;
+                iterateChildren(nodep);
+                m_graphing = false;
+            }
+            // Use graph to find tristate signals
+            m_tgraph.graphWalk(nodep);
+            // Build the LHS drivers map for this module
+            iterateChildren(nodep);
+            // Insert new logic for all tristates
+            insertTristates(nodep);
         }
-        // Use graph to find tristate signals
-        m_tgraph.graphWalk(nodep);
-        // Build the LHS drivers map for this module
-        iterateChildren(nodep);
-        // Insert new logic for all tristates
-        insertTristates(nodep);
-        m_modp = NULL;
+        m_modp = origModp;
+        m_graphing = origGraphing;
+        m_unique = origUnique;
+        m_lhsmap = origLhsmap;
+        m_tgraph.clear();  // Recursion not supported
     }
 
-    virtual void visit(AstNodeFTask* nodep) {
+    virtual void visit(AstNodeFTask* nodep) VL_OVERRIDE {
         // don't deal with functions
     }
 
-    virtual void visit(AstCaseItem* nodep) {
+    virtual void visit(AstCaseItem* nodep) VL_OVERRIDE {
         // don't deal with casez compare '???? values
         iterateAndNextNull(nodep->bodysp());
     }
 
-    virtual void visit(AstCell* nodep) {
+    virtual void visit(AstCell* nodep) VL_OVERRIDE {
         m_cellp = nodep;
         m_alhs = false;
         iterateChildren(nodep);
         m_cellp = NULL;
     }
 
-    virtual void visit(AstNetlist* nodep) {
+    virtual void visit(AstNetlist* nodep) VL_OVERRIDE {
         iterateChildrenBackwards(nodep);
     }
 
     // Default: Just iterate
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         checkUnhandled(nodep);
     }
