@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -38,22 +34,23 @@
 
 class WidthRemoveVisitor : public AstNVisitor {
 private:
-    // VISITORS
-    virtual void visit(AstSigned* nodep) {
-        replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()); VL_DANGLING(nodep);
-    }
-    virtual void visit(AstUnsigned* nodep) {
-        replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()); VL_DANGLING(nodep);
-    }
-    virtual void visit(AstNode* nodep) {
-        iterateChildren(nodep);
-    }
+    // METHODS
     void replaceWithSignedVersion(AstNode* nodep, AstNode* newp) {
-        UINFO(6," Replace "<<nodep<<" w/ "<<newp<<endl);
+        UINFO(6, " Replace " << nodep << " w/ " << newp << endl);
         nodep->replaceWith(newp);
         newp->dtypeFrom(nodep);
-        pushDeletep(nodep); VL_DANGLING(nodep);
+        VL_DO_DANGLING(pushDeletep(nodep), nodep);
     }
+
+    // VISITORS
+    virtual void visit(AstSigned* nodep) VL_OVERRIDE {
+        VL_DO_DANGLING(replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()), nodep);
+    }
+    virtual void visit(AstUnsigned* nodep) VL_OVERRIDE {
+        VL_DO_DANGLING(replaceWithSignedVersion(nodep, nodep->lhsp()->unlinkFrBack()), nodep);
+    }
+    virtual void visit(AstNode* nodep) VL_OVERRIDE { iterateChildren(nodep); }
+
 public:
     // CONSTRUCTORS
     WidthRemoveVisitor() {}
@@ -114,7 +111,7 @@ private:
         return nodep;
     }
     // VISITORS
-    virtual void visit(AstConst* nodep) {
+    virtual void visit(AstConst* nodep) VL_OVERRIDE {
         UASSERT_OBJ(nodep->dtypep(), nodep, "No dtype");
         iterate(nodep->dtypep());  // Do datatype first
         if (AstConst* newp = newIfConstCommitSize(nodep)) {
@@ -122,19 +119,19 @@ private:
             AstNode* oldp = nodep; nodep = newp;
             //if (debug()>4) oldp->dumpTree(cout, "  fixConstSize_old: ");
             //if (debug()>4) newp->dumpTree(cout, "              _new: ");
-            pushDeletep(oldp); VL_DANGLING(oldp);
+            VL_DO_DANGLING(pushDeletep(oldp), oldp);
         }
         editDType(nodep);
     }
-    virtual void visit(AstNodeDType* nodep) {
+    virtual void visit(AstNodeDType* nodep) VL_OVERRIDE {
         visitIterateNodeDType(nodep);
     }
-    virtual void visit(AstNodeUOrStructDType* nodep) {
+    virtual void visit(AstNodeUOrStructDType* nodep) VL_OVERRIDE {
         if (nodep->user1SetOnce()) return;  // Process once
         visitIterateNodeDType(nodep);
         nodep->clearCache();
     }
-    virtual void visit(AstParamTypeDType* nodep) {
+    virtual void visit(AstParamTypeDType* nodep) VL_OVERRIDE {
         if (nodep->user1SetOnce()) return;  // Process once
         visitIterateNodeDType(nodep);
         // Move to type table as all dtype pointers must resolve there
@@ -153,11 +150,11 @@ private:
         nodep->virtRefDTypep(editOneDType(nodep->virtRefDTypep()));
         nodep->virtRefDType2p(editOneDType(nodep->virtRefDType2p()));
     }
-    virtual void visit(AstNodePreSel* nodep) {  // LCOV_EXCL_LINE
+    virtual void visit(AstNodePreSel* nodep) VL_OVERRIDE {  // LCOV_EXCL_LINE
         // This check could go anywhere after V3Param
         nodep->v3fatalSrc("Presels should have been removed before this point");
     }
-    virtual void visit(AstNode* nodep) {
+    virtual void visit(AstNode* nodep) VL_OVERRIDE {
         iterateChildren(nodep);
         editDType(nodep);
     }
