@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2019 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -37,17 +33,22 @@ private:
     vluint64_t m_bucketsCovered;  ///< Num buckets with sufficient coverage
 
 private:
-    static inline vluint64_t covBit(vluint64_t point) { return 1ULL<<(point & 63); }
+    static inline vluint64_t covBit(vluint64_t point) { return 1ULL << (point & 63); }
     inline vluint64_t allocSize() const { return sizeof(vluint64_t) * m_dataSize / 64; }
     void allocate(vluint64_t point) {
         vluint64_t oldsize = m_dataSize;
-        if (m_dataSize<point) m_dataSize=(point+64) & ~63ULL;  // Keep power of two
+        if (m_dataSize < point) m_dataSize = (point + 64) & ~63ULL;  // Keep power of two
         m_dataSize *= 2;
-        //UINFO(9, "Realloc "<<allocSize()<<" for "<<point<<"  "<<cvtToHex(m_datap)<<endl);
+        // UINFO(9, "Realloc "<<allocSize()<<" for "<<point<<"  "<<cvtToHex(m_datap)<<endl);
         vluint64_t* newp = (vluint64_t*)realloc(m_datap, allocSize());
-        if (!newp) { free(m_datap); v3fatal("Out of memory increasing buckets"); }
+        if (!newp) {
+            free(m_datap);
+            v3fatal("Out of memory increasing buckets");
+        }
         m_datap = newp;
-        for (vluint64_t i=oldsize; i<m_dataSize; i+=64) m_datap[i/64] = 0;
+        for (vluint64_t i = oldsize; i < m_dataSize; i += 64) {
+            m_datap[i / 64] = 0;
+        }
     }
 
 public:
@@ -60,7 +61,7 @@ public:
     }
     ~VlcBuckets() {
         m_dataSize = 0;
-        free(m_datap); m_datap=NULL;
+        free(m_datap); m_datap = NULL;
     }
 
     // ACCESSORS
@@ -70,9 +71,9 @@ public:
     // METHODS
     void addData(vluint64_t point, vluint64_t hits) {
         if (hits >= sufficient()) {
-            //UINFO(9,"     addData "<<point<<" "<<hits<<" size="<<m_dataSize<<endl);
+            // UINFO(9,"     addData "<<point<<" "<<hits<<" size="<<m_dataSize<<endl);
             if (point >= m_dataSize) allocate(point);
-            m_datap[point/64] |= covBit(point);
+            m_datap[point / 64] |= covBit(point);
             m_bucketsCovered++;
         }
     }
@@ -80,55 +81,52 @@ public:
         if (point >= m_dataSize) {
             return;
         } else {
-            m_datap[point/64] &= ~covBit(point);
+            m_datap[point / 64] &= ~covBit(point);
         }
     }
     bool exists(vluint64_t point) const {
         if (point >= m_dataSize) {
             return false;
         } else {
-            return (m_datap[point/64] & covBit(point)) ? 1:0;
+            return (m_datap[point / 64] & covBit(point)) ? 1 : 0;
         }
     }
     vluint64_t hits(vluint64_t point) const {
         if (point >= m_dataSize) {
             return 0;
         } else {
-            return (m_datap[point/64] & covBit(point)) ? 1:0;
+            return (m_datap[point / 64] & covBit(point)) ? 1 : 0;
         }
     }
     vluint64_t popCount() const {
         vluint64_t pop = 0;
-        for (vluint64_t i=0; i<m_dataSize; i++) {
+        for (vluint64_t i = 0; i < m_dataSize; i++) {
             if (hits(i)) pop++;
         }
         return pop;
     }
     vluint64_t dataPopCount(const VlcBuckets& remaining) {
         vluint64_t pop = 0;
-        for (vluint64_t i=0; i<m_dataSize; i++) {
+        for (vluint64_t i = 0; i < m_dataSize; i++) {
             if (hits(i) && remaining.hits(i)) pop++;
         }
         return pop;
     }
     void orData(const VlcBuckets& ordata) {
-        for (vluint64_t i=0; i<m_dataSize; i++) {
-            if (hits(i) && ordata.hits(i)) {
-                clearHits(i);
-            }
+        for (vluint64_t i = 0; i < m_dataSize; i++) {
+            if (hits(i) && ordata.hits(i)) clearHits(i);
         }
     }
 
     void dump() const {
-        cout<<"#     ";
-        for (vluint64_t i=0; i<m_dataSize; i++) {
-            if (hits(i)) cout<<","<<i;
+        cout << "#     ";
+        for (vluint64_t i = 0; i < m_dataSize; i++) {
+            if (hits(i)) cout << "," << i;
         }
-        cout<<endl;
+        cout << endl;
     }
 };
 
-
 //######################################################################
 
 #endif  // guard
