@@ -6,15 +6,11 @@
 //
 //*************************************************************************
 //
-// Copyright 2003-2020 by Wilson Snyder.  This program is free software; you can
-// redistribute it and/or modify it under the terms of either the GNU
+// Copyright 2003-2020 by Wilson Snyder. This program is free software; you
+// can redistribute it and/or modify it under the terms of either the GNU
 // Lesser General Public License Version 3 or the Perl Artistic License
 // Version 2.0.
-//
-// Verilator is distributed in the hope that it will be useful,
-// but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 //
 //*************************************************************************
 
@@ -71,19 +67,20 @@ public:
 
     // METHODS
     static void dumpHeader() {
-        cout<<"Tests:\n";
-        //cout<<"  Testrun, Computrons,";  // Currently not loaded
-        cout<<"  Covered,     Rank,  RankPts,  Filename"<<endl;
+        cout << "Tests:\n";
+        // cout<<"  Testrun, Computrons,";  // Currently not loaded
+        cout << "  Covered,     Rank,  RankPts,  Filename" << endl;
     }
     void dump(bool bucketsToo) {
-        if (testrun() || computrons()!=0.0) {  // currently unused // LCOV_EXCL_LINE
-            cout<<"  "<<std::setw(8)<<std::setfill('0')<<testrun()  // LCOV_EXCL_LINE
-                <<",  "<<std::setw(7)<<std::setfill(' ')<<computrons()<<",";  // LCOV_EXCL_LINE
+        if (testrun() || computrons() != 0.0) {  // currently unused // LCOV_EXCL_LINE
+            cout << "  " << std::setw(8) << std::setfill('0') << testrun()  // LCOV_EXCL_LINE
+                 << ",  " << std::setw(7) << std::setfill(' ') << computrons()
+                 << ",";  // LCOV_EXCL_LINE
         }
-        cout<<"  "<<std::setw(7)<<std::setfill(' ')<<bucketsCovered()
-            <<",  "<<std::setw(7)<<std::setfill(' ')<<rank()
-            <<",  "<<std::setw(7)<<std::setfill(' ')<<rankPoints()
-            <<",  \""<<name()<<"\""<<endl;
+        cout << "  " << std::setw(7) << std::setfill(' ') << bucketsCovered();
+        cout << ",  " << std::setw(7) << std::setfill(' ') << rank();
+        cout << ",  " << std::setw(7) << std::setfill(' ') << rankPoints();
+        cout << ",  \"" << name() << "\"" << endl;
         if (bucketsToo) m_buckets.dump();
     }
 };
@@ -95,6 +92,7 @@ class VlcTests {
 public:
     // TYPES
     typedef std::vector<VlcTest*> ByName;
+
 private:
     // MEMBERS
     ByName m_tests;  //< List of all tests
@@ -109,16 +107,16 @@ public:
     // CONSTRUCTORS
     VlcTests() {}
     ~VlcTests() {
-        for (VlcTests::ByName::iterator it=begin(); it!=end(); ++it) {
-            delete *it; *it=NULL;
+        for (VlcTests::ByName::iterator it = begin(); it != end(); ++it) {
+            VL_DO_CLEAR(delete *it, *it = NULL);
         }
     }
 
     // METHODS
     void dump(bool bucketsToo) {
-        UINFO(2,"dumpTests...\n");
+        UINFO(2, "dumpTests...\n");
         VlcTest::dumpHeader();
-        for (VlcTests::ByName::iterator it=begin(); it!=end(); ++it) {
+        for (VlcTests::ByName::const_iterator it = begin(); it != end(); ++it) {
             (*it)->dump(bucketsToo);
         }
     }
