@@ -2,10 +2,11 @@
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
 use IO::File;
 use strict;
@@ -34,7 +35,10 @@ sub check {
     for my $author (sort keys %Authors) {
         print "Check: $author\n" if $Self->{verbose};
         if (!$Contributors{$author}) {
-            error("Certify your contribution by appending '$author' to CONTRIBUTORS");
+            error("Certify your contribution by appending '$author' to docs/CONTRIBUTORS.\n"
+                  ."   If '$author' is not your real name, please fix 'name=' in ~/.gitconfig\n"
+                  ."   Also check your https://github.com account's Settings->Profile->Name\n"
+                  ."   matches your ~/.gitconfig 'name='.\n");
         }
     }
 }
