@@ -2,21 +2,19 @@
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2008 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2008 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
-scenarios(vlt_all => 1);
+scenarios(linter => 1);
 
 top_filename("t/t_lint_setout_bad.v");
 
-compile(
-    v_flags2 => ["--lint-only -Oi"],
+lint(
+    verilator_flags2 => ["--lint-only -Oi"],
     fails => 1,
-    verilator_make_gcc => 0,
-    make_top_shell => 0,
-    make_main => 0,
     expect_filename => $Self->{golden_filename},
     );
 
