@@ -2,17 +2,18 @@
 if (!$::Driver) { use FindBin; exec("$FindBin::Bin/bootstrap.pl", @ARGV, $0); die; }
 # DESCRIPTION: Verilator: Verilog Test driver/expect definition
 #
-# Copyright 2003 by Wilson Snyder. This program is free software; you can
-# redistribute it and/or modify it under the terms of either the GNU
+# Copyright 2003 by Wilson Snyder. This program is free software; you
+# can redistribute it and/or modify it under the terms of either the GNU
 # Lesser General Public License Version 3 or the Perl Artistic License
 # Version 2.0.
+# SPDX-License-Identifier: LGPL-3.0-only OR Artistic-2.0
 
-scenarios(vlt => 1);
+scenarios(linter => 1);
 
 top_filename("t/t_param_default_bad.v");
 
-compile(
-    v_flags2 => ["--lint-only --language 1800-2005"],
+lint(
+    verilator_flags2 => ["--lint-only --language 1800-2005"],
     fails => 1,
     expect_filename => $Self->{golden_filename},
     );
