@@ -2,17 +2,15 @@
 //
 // DESCRIPTION: Verilator: Verilog Test module
 //
-// This file ONLY is placed into the Public Domain, for any use,
-// without warranty, 2008 by Wilson Snyder.
+// This file ONLY is placed under the Creative Commons Public Domain, for
+// any use, without warranty, 2008 by Wilson Snyder.
+// SPDX-License-Identifier: CC0-1.0
 
 #include <verilated.h>
 #include <verilated_vcd_c.h>
 
 #include VM_PREFIX_INCLUDE
 
-#define STRINGIFY(x) STRINGIFY2(x)
-#define STRINGIFY2(x) #x
-
 unsigned long long main_time = 0;
 double sc_time_stamp() { return ((double)main_time) / VL_TIME_MULTIPLIER; }
 
@@ -28,7 +26,7 @@ int main(int argc, char** argv, char** env) {
 
     top->trace(tfp, 99);
 
-    tfp->open(STRINGIFY(TEST_OBJ_DIR) "/simx.vcd");
+    tfp->open(VL_STRINGIFY(TEST_OBJ_DIR) "/simx.vcd");
 
     top->clk = 0;
 
